/**
 * Represents an error returned by the Autodiscover service.
 * @sealed
 */
export declare class AutodiscoverError {
    private time;
    private id;
    private errorCode;
    private message;
    private debugData;
    /**
     * Gets the time when the error was returned.
     */
    get Time(): string;
    /**
     * Gets a hash of the name of the computer that is running Microsoft Exchange Server that has the Client Access server role installed.
     */
    get Id(): string;
    /**
     * Gets the error code.
     */
    get ErrorCode(): number;
    /**
     * Gets the error message.
     */
    get Message(): string;
    /**
     * Gets the debug data.
     */
    get DebugData(): string;
    /**
     * Initializes a new instance of the **AutodiscoverError** class.
     */
    private constructor();
    /**
     * Parses the XML Js Object creates an Autodiscover error.
     *
     * @param   {any}   jsObject   The object.
     * @return  {AutodiscoverError}            An Autodiscover error.
     */
    Parse(jsObject: any): AutodiscoverError;
}
