import { AutodiscoverResponse } from "./Responses/AutodiscoverResponse";
/**
 * Represents a collection of responses to a call to the Autodiscover service.
 * @typeparam {TResponse} The type of the responses in the collection.
 */
export declare abstract class AutodiscoverResponseCollection<TResponse extends AutodiscoverResponse> extends AutodiscoverResponse {
    private responses;
    /**
     * Gets the number of responses in the collection.
     */
    get Count(): number;
    /**
     * Gets the response at the specified index.
     *
     * @param   {number}   index   Index.
     * @returns {TResponse} TResponse at the index
     */
    __thisIndexer(index: number): TResponse;
    /**
     * Gets an enumerator that iterates through the elements of the collection.
     *
     * @return  {TResponse[]}      An IEnumerator for the collection.
     */
    GetEnumerator(): TResponse[];
    /**
     * Loads the response collection from XML.
     *
     * @param   {any} jsObject  Json Object converted from XML.
     */
    private LoadResponseCollectionFromXmlJsObject;
}
