/**
 * Represents a sharing location.
 * @sealed
 */
export declare class DocumentSharingLocation {
    /**
     * The URL of the web service to use to manipulate documents at the sharing location.
     */
    private serviceUrl;
    /**
     * The URL of the sharing location (for viewing the contents in a web browser).
     */
    private locationUrl;
    /**
     * The display name of the location.
     */
    private displayName;
    /**
     * The set of file extensions that are allowed at the location.
     */
    private supportedFileExtensions;
    /**
     * Indicates whether external users (outside the enterprise/tenant) can view documents at the location.
     */
    private externalAccessAllowed;
    /**
     * Indicates whether anonymous users can view documents at the location.
     */
    private anonymousAccessAllowed;
    /**
     * Indicates whether the user can modify permissions for documents at the location.
     */
    private canModifyPermissions;
    /**
     * Indicates whether this location is the user's default location. This will generally be their My Site.
     */
    private isDefault;
    /**
     * Gets the URL of the web service to use to manipulate documents at the sharing location.
     */
    get ServiceUrl(): string;
    /**
     * Gets the URL of the sharing location (for viewing the contents in a web browser).
     */
    get LocationUrl(): string;
    /**
     * Gets the display name of the location.
     */
    get DisplayName(): string;
    /**
     * Gets the space-separated list of file extensions that are allowed at the location.
     * @remarks Example:  "docx pptx xlsx"
     */
    get SupportedFileExtensions(): string[];
    /**
     * Gets a flag indicating whether external users (outside the enterprise/tenant) can view documents at the location.
     */
    get ExternalAccessAllowed(): boolean;
    /**
     * Gets a flag indicating whether anonymous users can view documents at the location.
     */
    get AnonymousAccessAllowed(): boolean;
    /**
     * Gets a flag indicating whether the user can modify permissions for documents at the location.
     * @remarks This will be true for the user's "My Site," for example. However, documents at team and project sites will typically be ACLed by the site owner, so the user will not be able to modify permissions. This will most likely by false even if the caller is the owner, to avoid surprises. They should go to SharePoint to modify permissions for team and project sites.
     */
    get CanModifyPermissions(): boolean;
    /**
     * Gets a flag indicating whether this location is the user's default location.  This will generally be their My Site.
     */
    get IsDefault(): boolean;
    /**
     * Initializes a new instance of the **DocumentSharingLocation** class.
     */
    private constructor();
}
