import { Dictionary } from "../../AltDictionary";
import { DomainSettingError } from "../DomainSettingError";
import { DomainSettingName } from "../../Enumerations/DomainSettingName";
import { AutodiscoverResponse } from "./AutodiscoverResponse";
/**
 * Represents the response to a GetDomainSettings call for an individual domain.
 * @sealed
 */
export declare class GetDomainSettingsResponse extends AutodiscoverResponse {
    private domain;
    private redirectTarget;
    private settings;
    private domainSettingErrors;
    /**
     * Gets the domain this response applies to.
     */
    get Domain(): string;
    /**
     * Gets the redirectionTarget (URL or email address)
     */
    get RedirectTarget(): string;
    /**
     * Gets the requested settings for the domain.
     */
    get Settings(): Dictionary<DomainSettingName, any>;
    /**
     * Gets error information for settings that could not be returned.
     */
    get DomainSettingErrors(): DomainSettingError[];
    /**
     * Initializes a new instance of the **GetDomainSettingsResponse** class.
     */
    constructor();
    /**
     * Loads the domain setting errors.
     *
     * @param   {any} jsObject  Json Object converted from XML.
     */
    private LoadDomainSettingErrorsFromXmlJsObject;
    /**
     * Reads domain setting from XML jsObject.
     *
     * @param   {any} jsObject  Json Object converted from XML.
     */
    private ReadSettingFromXmlJsObject;
}
