import { Dictionary } from "../../AltDictionary";
import { UserSettingError } from "../UserSettingError";
import { UserSettingName } from "../../Enumerations/UserSettingName";
import { AutodiscoverResponse } from "./AutodiscoverResponse";
/**
 * Represents the response to a GetUsersSettings call for an individual user.
 * @sealed
 */
export declare class GetUserSettingsResponse extends AutodiscoverResponse {
    private smtpAddress;
    private redirectTarget;
    private settings;
    private userSettingErrors;
    /**
     * Gets the SMTP address this response applies to.
     */
    get SmtpAddress(): string;
    /**
     * Gets the redirectionTarget (URL or email address)
     */
    get RedirectTarget(): string;
    /**
     * Gets the requested settings for the user.
     */
    get Settings(): Dictionary<UserSettingName, any>;
    /**
     * Gets error information for settings that could not be returned.
     */
    get UserSettingErrors(): UserSettingError[];
    /**
     * Initializes a new instance of the **GetUserSettingsResponse** class.
     */
    constructor();
    /**
     * Loads the user setting errors.
     *
     * @param   {any} jsObject  Json Object converted from XML.
     */
    private LoadUserSettingErrorsFromXmlJsObject;
    /**
     * Reads user setting from XML jsObject.
     *
     * @param   {any} jsObject  Json Object converted from XML.
     */
    ReadSettingFromXmlJsObject(jsObject: any): void;
    /**
     * Tries the get the user setting value.
     *
     * @param   {UserSettingName}   setting   The setting.
     * @return  {T}  The setting value.
     */
    GetSettingValue<T>(setting: UserSettingName): T;
}
