import { DateTime } from "../DateTime";
import { ComplexProperty } from "./ComplexProperty";
/**
 * Represents an attachment to an item.
 */
export declare class Attachment extends ComplexProperty {
    private owner;
    private id;
    private name;
    private contentType;
    private contentId;
    private contentLocation;
    private size;
    private lastModifiedTime;
    private isInline;
    private service;
    /**
     * Gets the Id of the attachment.
     */
    get Id(): string;
    set Id(value: string);
    /***
     * Gets or sets the name of the attachment.
     */
    get Name(): string;
    set Name(value: string);
    /**
     * Gets or sets the content type of the attachment.
     */
    get ContentType(): string;
    set ContentType(value: string);
    /**
     * Gets or sets the content Id of the attachment. ContentId can be used as a custom way to identify an attachment in order to reference it from within the body of the item the attachment belongs to.
     */
    get ContentId(): string;
    set ContentId(value: string);
    /**
     * Gets or sets the content location of the attachment. ContentLocation can be used to associate an attachment with a Url defining its location on the Web.
     */
    get ContentLocation(): string;
    set ContentLocation(value: string);
    /**
     * Gets the size of the attachment.
     */
    get Size(): number;
    set Size(value: number);
    /**
     * Gets the date and time when this attachment was last modified.
     */
    get LastModifiedTime(): DateTime;
    set LastModifiedTime(value: DateTime);
    /**
     * Gets or sets a value indicating whether this is an inline attachment. Inline attachments are not visible to end users.
     */
    get IsInline(): boolean;
    set IsInline(value: boolean);
    /**
     * Gets the name of the XML element.
     *
     * @return  {string}      XML element name.
     */
    GetXmlElementName(): string;
    /**
     * Loads the attachment. Calling this method results in a call to EWS.
     */
    Load(): Promise<void>;
    /**
     * Loads the attachment id from json.
     *
     * @param   {any}   jsonObject   The json object.
     */
    private LoadAttachmentIdFromXMLJsObject;
}
