import { ISelfValidate } from "../../Interfaces/ISelfValidate";
import { OofExternalAudience } from "../../Enumerations/OofExternalAudience";
import { OofReply } from "../../Misc/Availability/OofReply";
import { OofState } from "../../Enumerations/OofState";
import { TimeWindow } from "../../Misc/Availability/TimeWindow";
import { ComplexProperty } from "../ComplexProperty";
/**
 * Represents a user's Out of Office (OOF) settings.
 */
export declare class OofSettings extends ComplexProperty implements ISelfValidate {
    private state;
    private externalAudience;
    private allowExternalOof;
    private duration;
    private internalReply;
    private externalReply;
    /**
     * Gets or sets the user's OOF state.
     *
     * @value The user's OOF state.
     */
    get State(): OofState;
    set State(value: OofState);
    /**
     * Gets or sets a value indicating who should receive external OOF messages.
     */
    get ExternalAudience(): OofExternalAudience;
    set ExternalAudience(value: OofExternalAudience);
    /**
     * Gets or sets the duration of the OOF status when State is set to OofState.Scheduled.
     */
    get Duration(): TimeWindow;
    set Duration(value: TimeWindow);
    /**
     * Gets or sets the OOF response sent other users in the user's domain or trusted domain.
     */
    get InternalReply(): OofReply;
    set InternalReply(value: OofReply);
    /**
     * Gets or sets the OOF response sent to addresses outside the user's domain or trusted domain.
     */
    get ExternalReply(): OofReply;
    set ExternalReply(value: OofReply);
    /**
     * Gets a value indicating the authorized external OOF notifications.
     */
    get AllowExternalOof(): OofExternalAudience;
    set AllowExternalOof(value: OofExternalAudience);
    /**
     * Initializes a new instance of OofSettings.
     */
    constructor();
    /**
     * Serializes an OofReply. Emits an empty OofReply in case the one passed in is null.
     *
     * @param   {OofReply}              oofReply         The oof reply.
     * @param   {EwsServiceXmlWriter}   writer           The writer.
     * @param   {string}                xmlElementName   Name of the XML element.
     */
    private SerializeOofReply;
    /**
     * Validates this instance.
     */
    Validate(): void;
}
