import { DelegatePermissions } from "./DelegatePermissions";
import { StandardUser } from "../Enumerations/StandardUser";
import { UserId } from "./UserId";
import { ComplexProperty } from "./ComplexProperty";
/**
 * Represents a delegate user.
 *
 * @sealed
 */
export declare class DelegateUser extends ComplexProperty {
    private userId;
    private permissions;
    private receiveCopiesOfMeetingMessages;
    private viewPrivateItems;
    /**
     * Gets the user Id of the delegate user.
     */
    get UserId(): UserId;
    /**
     * Gets the list of delegate user's permissions.
     */
    get Permissions(): DelegatePermissions;
    /**
     * Gets or sets a value indicating if the delegate user should receive copies of meeting requests.
     */
    get ReceiveCopiesOfMeetingMessages(): boolean;
    set ReceiveCopiesOfMeetingMessages(value: boolean);
    /**
     * Gets or sets a value indicating if the delegate user should be able to view the principal's private items.
     */
    get ViewPrivateItems(): boolean;
    set ViewPrivateItems(value: boolean);
    /**
     * Initializes a new instance of the **DelegateUser** class.
     */
    constructor();
    /**
     * Initializes a new instance of the **DelegateUser** class.
     *
     * @param   {string}   primarySmtpAddress   The primary SMTP address of the delegate user.
     */
    constructor(primarySmtpAddress: string);
    /**
     * Initializes a new instance of the **DelegateUser** class.
     *
     * @param   {StandardUser}   standardUser   The standard delegate user.
     */
    constructor(standardUser: StandardUser);
}
