import { ComplexProperty } from "./ComplexProperty";
import { Dictionary } from "../AltDictionary";
import { DictionaryEntryProperty } from "./DictionaryEntryProperty";
import { ICustomUpdateSerializer } from "../Interfaces/ICustomXmlUpdateSerializer";
/**
 * Represents a generic dictionary that can be sent to or retrieved from EWS.
 *
 * @typeparam   <TKey>      The type of key.
 * @typeparam   <TEntry>    The type of entry.
 */
export declare abstract class DictionaryProperty<TKey, TEntry extends DictionaryEntryProperty<TKey>> extends ComplexProperty implements ICustomUpdateSerializer {
    private dictionaryKeyType;
    private dictionaryKeyTypeEnum;
    private dictionaryKeyDelegate;
    private entries;
    private removedEntries;
    private addedEntries;
    private modifiedEntries;
    /**
     * Gets the entries.
     *
     * @value   The entries.
     */
    get Entries(): Dictionary<TKey, TEntry>;
    /**
     * Determines whether this instance contains the specified key.
     *
     * @param   {TKey}      key   The key.
     * @return  {boolean}   true if this instance contains the specified key; otherwise, false.
     */
    Contains(key: TKey): boolean;
    /**
     * Entry was changed.
     *
     * @param   {}   complexProperty   The complex property.
     */
    private EntryChanged;
    /**
     * Remove entry based on key.
     *
     * @param   {TKey}   key   The key.
     */
    InternalRemove(key: TKey): void;
    /**
     * Writes the URI to XML.
     *
     * @param   {EwsServiceXmlWriter}   writer   The writer.
     * @param   {TKey}                  key      The key.
     */
    private WriteUriToXml;
}
