import { FolderPermissionLevel } from "../Enumerations/FolderPermissionLevel";
import { FolderPermissionReadAccess } from "../Enumerations/FolderPermissionReadAccess";
import { PermissionScope } from "../Enumerations/PermissionScope";
import { StandardUser } from "../Enumerations/StandardUser";
import { UserId } from "./UserId";
import { ComplexProperty } from "./ComplexProperty";
/**
 * Represents a permission on a folder.
 *
 * @sealed
 */
export declare class FolderPermission extends ComplexProperty {
    private static defaultPermissions;
    /**
     * Variants of pre-defined permission levels that Outlook also displays with the same levels.
     */
    private static levelVariants;
    private userId;
    private canCreateItems;
    private canCreateSubFolders;
    private isFolderOwner;
    private isFolderVisible;
    private isFolderContact;
    private editItems;
    private deleteItems;
    private readItems;
    private permissionLevel;
    /**
     * Gets the Id of the user the permission applies to.
     */
    get UserId(): UserId;
    set UserId(value: UserId);
    /**
     * Gets or sets a value indicating whether the user can create new items.
     */
    get CanCreateItems(): boolean;
    set CanCreateItems(value: boolean);
    /**
     * Gets or sets a value indicating whether the user can create sub-folders.
     */
    get CanCreateSubFolders(): boolean;
    set CanCreateSubFolders(value: boolean);
    /**
     * Gets or sets a value indicating whether the user owns the folder.
     */
    get IsFolderOwner(): boolean;
    set IsFolderOwner(value: boolean);
    /**
     * Gets or sets a value indicating whether the folder is visible to the user.
     */
    get IsFolderVisible(): boolean;
    set IsFolderVisible(value: boolean);
    /**
     * Gets or sets a value indicating whether the user is a contact for the folder.
     */
    get IsFolderContact(): boolean;
    set IsFolderContact(value: boolean);
    /**
     * Gets or sets a value indicating if/how the user can edit existing items.
     */
    get EditItems(): PermissionScope;
    set EditItems(value: PermissionScope);
    /**
     * Gets or sets a value indicating if/how the user can delete existing items.
     */
    get DeleteItems(): PermissionScope;
    set DeleteItems(value: PermissionScope);
    /**
     * Gets or sets the read items access permission.
     */
    get ReadItems(): FolderPermissionReadAccess;
    set ReadItems(value: FolderPermissionReadAccess);
    /**
     * Gets or sets the permission level.
     */
    get PermissionLevel(): FolderPermissionLevel;
    set PermissionLevel(value: FolderPermissionLevel);
    /**
     * Gets the permission level that Outlook would display for this folder permission.
     */
    get DisplayPermissionLevel(): FolderPermissionLevel;
    /**
     * Initializes a new instance of the **FolderPermission** class.
     */
    constructor();
    /**
     * Initializes a new instance of the **FolderPermission** class.
     *
     * @param   {UserId}                    userId            The Id of the user  the permission applies to.
     * @param   {FolderPermissionLevel}     permissionLevel   The level of the permission.
     */
    constructor(userId: UserId, permissionLevel: FolderPermissionLevel);
    /**
     * Initializes a new instance of the **FolderPermission** class.
     *
     * @param   {string}                    primarySmtpAddress  The primary SMTP address of the user the permission applies to.
     * @param   {FolderPermissionLevel}     permissionLevel     The level of the permission.
     */
    constructor(primarySmtpAddress: string, permissionLevel: FolderPermissionLevel);
    /**
     * Initializes a new instance of the **FolderPermission** class.
     *
     * @param   {StandardUser}              standardUser        The standard user the permission applies to.
     * @param   {FolderPermissionLevel}     permissionLevel     The level of the permission.
     */
    constructor(standardUser: StandardUser, permissionLevel: FolderPermissionLevel);
    /**
     * Determines the permission level of this folder permission based on its individual settings, and sets the PermissionLevel property accordingly.
     */
    private AdjustPermissionLevel;
    /**
     * Copies the values of the individual permissions of the specified folder permission to this folder permissions.
     *
     * @param   {FolderPermission}   permission   The folder permission to copy the values from.
     */
    private AssignIndividualPermissions;
    /**
     * Create a copy of this FolderPermission instance.
     *
     * @return  {FolderPermission}      Clone of this instance.
     */
    private Clone;
    /**
     * Determines whether the specified folder permission is the same as this one. The comparison does not take UserId and PermissionLevel into consideration.
     *
     * @param   {FolderPermission}  permission   The folder permission to compare with this folder permission.
     * @return  {boolean}           True is the specified folder permission is equal to this one, false otherwise.
     */
    private IsEqualTo;
    /**
     * Property was changed.
     *
     * @param   {ComplexProperty}   complexProperty   The complex property.
     */
    private PropertyChanged;
}
