import { Folder } from "../Core/ServiceObjects/Folders/Folder";
import { FolderPermission } from "./FolderPermission";
import { ComplexPropertyCollection } from "./ComplexPropertyCollection";
/**
 * Represents a collection of folder permissions.
 *
 * @sealed
 */
export declare class FolderPermissionCollection extends ComplexPropertyCollection<FolderPermission> {
    private isCalendarFolder;
    private unknownEntries;
    /**
     * Gets the name of the inner collection XML element.
     *
     * @value   XML element name.
     */
    private get InnerCollectionXmlElementName();
    /**
     * Gets the name of the collection item XML element.
     *
     * @value   XML element name.
     */
    private get CollectionItemXmlElementName();
    /**
     * Gets a list of unknown user Ids in the collection.
     */
    get UnknownEntries(): string[];
    /**
     * Initializes a new instance of the **FolderPermissionCollection** class.
     *
     * @param   {Folder}   owner   The folder owner.
     */
    constructor(owner: Folder);
    /**
     * Adds a permission to the collection.
     *
     * @param   {FolderPermission}   permission   The permission to add.
     */
    Add(permission: FolderPermission): void;
    /**
     * Adds the specified permissions to the collection.
     *
     * @param   {FolderPermission[]}   permissions   The permissions to add.
     */
    AddRange(permissions: FolderPermission[]): void;
    /**
     * Clears this collection.
     */
    Clear(): void;
    /**
     * Removes a permission from the collection.
     *
     * @param   {FolderPermission}  permission   The permission to remove.
     * @return  {boolean}           True if the folder permission was successfully removed from the collection, false otherwise.
     */
    Remove(permission: FolderPermission): boolean;
    /**
     * Removes a permission from the collection.
     *
     * @param   {number}   index   The zero-based index of the permission to remove.
     */
    RemoveAt(index: number): void;
}
