import { DateTime } from "../../../DateTime";
import { DayOfTheWeekIndex } from "../../../Enumerations/DayOfTheWeekIndex";
import { DayOfTheWeek } from "../../../Enumerations/DayOfTheWeek";
import { IntervalPattern } from "./Recurrence.IntervalPattern";
/**
 * Represents a recurrence pattern where each occurrence happens on a relative day a specific number of months after the previous one.
*/
export declare class RelativeMonthlyPattern extends IntervalPattern {
    private dayOfTheWeek;
    private dayOfTheWeekIndex;
    /**
     * Gets or sets the relative position of the day specified in DayOfTheWeek within the month.
     */
    get DayOfTheWeekIndex(): DayOfTheWeekIndex;
    set DayOfTheWeekIndex(value: DayOfTheWeekIndex);
    /**
     * The day of the week when each occurrence happens.
     */
    get DayOfTheWeek(): DayOfTheWeek;
    set DayOfTheWeek(value: DayOfTheWeek);
    /**
     * Initializes a new instance of the **RelativeMonthlyPattern** class.
     */
    constructor();
    /**
     * Initializes a new instance of the **RelativeMonthlyPattern** class.
     *
     * @param   {DateTime}              startDate           The date and time when the recurrence starts.
     * @param   {number}                interval            The number of months between each occurrence.
     * @param   {DayOfTheWeek}          dayOfTheWeek        The day of the week each occurrence happens.
     * @param   {DayOfTheWeekIndex}   dayOfTheWeekIndex   The relative position of the day within the month.
     */
    constructor(startDate: DateTime, interval: number, dayOfTheWeek: DayOfTheWeek, dayOfTheWeekIndex: DayOfTheWeekIndex);
}
