import { DateTime } from "../../../DateTime";
import { DayOfTheWeekIndex } from "../../../Enumerations/DayOfTheWeekIndex";
import { DayOfTheWeek } from "../../../Enumerations/DayOfTheWeek";
import { Month } from "../../../Enumerations/Month";
import { Recurrence } from "./Recurrence";
/**
 * Represents a recurrence pattern where each occurrence happens on a relative day every year.
 */
export declare class RelativeYearlyPattern extends Recurrence {
    private dayOfTheWeek;
    private dayOfTheWeekIndex;
    private month;
    /**
     * Gets or sets the relative position of the day specified in DayOfTheWeek within the month.
     */
    get DayOfTheWeekIndex(): DayOfTheWeekIndex;
    set DayOfTheWeekIndex(value: DayOfTheWeekIndex);
    /**
     * Gets or sets the day of the week when each occurrence happens.
     */
    get DayOfTheWeek(): DayOfTheWeek;
    set DayOfTheWeek(value: DayOfTheWeek);
    /**
     * Gets or sets the month of the year when each occurrence happens.
     */
    get Month(): Month;
    set Month(value: Month);
    /**
     * Initializes a new instance of the **RelativeYearlyPattern** class.
     */
    constructor();
    /**
     * Initializes a new instance of the **RelativeYearlyPattern** class.
     *
     * @param   {DateTime}              startDate           The date and time when the recurrence starts.
     * @param   {Month}                 month               The month of the year each occurrence happens.
     * @param   {DayOfTheWeek}          dayOfTheWeek        The day of the week each occurrence happens.
     * @param   {DayOfTheWeekIndex}     dayOfTheWeekIndex   The relative position of the day within the month.
     */
    constructor(startDate: DateTime, month: Month, dayOfTheWeek: DayOfTheWeek, dayOfTheWeekIndex: DayOfTheWeekIndex);
}
