import { DateTime } from "../../../DateTime";
import { DayOfTheWeek } from "../../../Enumerations/DayOfTheWeek";
import { DayOfTheWeekCollection } from "../DayOfTheWeekCollection";
import { DayOfWeek } from "../../../Enumerations/DayOfWeek";
import { IntervalPattern } from "./Recurrence.IntervalPattern";
/**
 * Represents a recurrence pattern where each occurrence happens on specific days a specific number of weeks after the previous one.
 */
export declare class WeeklyPattern extends IntervalPattern {
    private daysOfTheWeek;
    private firstDayOfWeek;
    /**
     * Gets the list of the days of the week when occurrences happen.
     */
    get DaysOfTheWeek(): DayOfTheWeekCollection;
    /**
     * Gets or sets the first day of the week for this recurrence.
     */
    get FirstDayOfWeek(): DayOfWeek;
    set FirstDayOfWeek(value: DayOfWeek);
    /**
     * Initializes a new instance of the **WeeklyPattern** class.
     */
    constructor();
    /**
     * Initializes a new instance of the **WeeklyPattern** class.
     *
     * @param   {DateTime}          startDate       The date and time when the recurrence starts.
     * @param   {number}            interval        The number of weeks between each occurrence.
     * @param   {DayOfTheWeek[]}    daysOfTheWeek   The days of the week when occurrences happen.
     */
    constructor(startDate: DateTime, interval: number, daysOfTheWeek: DayOfTheWeek[]);
    /**
     * Change event handler.
     *
     * @param   {ComplexProperty}   complexProperty   The complex property.
     */
    private DaysOfTheWeekChanged;
}
