import { DailyPattern } from "./Recurrence.DailyPattern";
import { DailyRegenerationPattern } from "./Recurrence.DailyRegenerationPattern";
import { DateTime } from "../../../DateTime";
import { IntervalPattern } from "./Recurrence.IntervalPattern";
import { MonthlyPattern } from "./Recurrence.MonthlyPattern";
import { MonthlyRegenerationPattern } from "./Recurrence.MonthlyRegenerationPattern";
import { RelativeMonthlyPattern } from "./Recurrence.RelativeMonthlyPattern";
import { RelativeYearlyPattern } from "./Recurrence.RelativeYearlyPattern";
import { WeeklyPattern } from "./Recurrence.WeeklyPattern";
import { WeeklyRegenerationPattern } from "./Recurrence.WeeklyRegenerationPattern";
import { YearlyPattern } from "./Recurrence.YearlyPattern";
import { YearlyRegenerationPattern } from "./Recurrence.YearlyRegenerationPattern";
import { ComplexProperty } from "../../ComplexProperty";
/**
 * Represents a recurrence pattern, as used by Appointment and Task items.
 */
export declare class Recurrence extends ComplexProperty {
    startDate: DateTime;
    numberOfOccurrences: number;
    endDate: DateTime;
    /**
     * Gets or sets the date and time when the recurrence start.
     */
    get StartDate(): DateTime;
    set StartDate(value: DateTime);
    /**
     * Gets a value indicating whether the pattern has a fixed number of occurrences or an end date.
     */
    get HasEnd(): boolean;
    /**
     * Gets or sets the number of occurrences after which the recurrence ends. Setting NumberOfOccurrences resets EndDate.
     */
    get NumberOfOccurrences(): number;
    set NumberOfOccurrences(value: number);
    /**
     * Gets or sets the date after which the recurrence ends. Setting EndDate resets NumberOfOccurrences.
     */
    get EndDate(): DateTime;
    set EndDate(value: DateTime);
    /**
     * Gets a property value or throw if null.
     *
     * @typeparam   {T}     Value type.
     * @param   {T}         value   The value.
     * @param   {string}    name    The property name.
     * @return  {T}         Property value
     */
    GetFieldValueOrThrowIfNull<T>(value: any, name: string): T;
    /**
     * Compares two objects by converting them to JSON and comparing their string values
     *
     * @param   {Recurrence}    otherRecurrence   object to compare to
     * @return  {boolean}       true if the objects serialize to the same string
     */
    IsSame(otherRecurrence: Recurrence): boolean;
    /**
     * Sets up this recurrence so that it never ends. Calling NeverEnds is equivalent to setting both NumberOfOccurrences and EndDate to null.
     */
    NeverEnds(): void;
}
export declare namespace Recurrence {
    var DailyPattern: new () => DailyPattern;
    var DailyRegenerationPattern: new () => DailyRegenerationPattern;
    var IntervalPattern: new () => IntervalPattern;
    var MonthlyPattern: new () => MonthlyPattern;
    var MonthlyRegenerationPattern: new () => MonthlyRegenerationPattern;
    var RelativeMonthlyPattern: new () => RelativeMonthlyPattern;
    var RelativeYearlyPattern: new () => RelativeYearlyPattern;
    var WeeklyPattern: new () => WeeklyPattern;
    var WeeklyRegenerationPattern: new () => WeeklyRegenerationPattern;
    var YearlyPattern: new () => YearlyPattern;
    var YearlyRegenerationPattern: new () => YearlyRegenerationPattern;
}
