import { RuleActions } from "./RuleActions";
import { RulePredicates } from "./RulePredicates";
import { ComplexProperty } from "./ComplexProperty";
/**
 * Represents a rule that automatically handles incoming messages.
 * A rule consists of a set of conditions and exceptions that determine whether or not a set of actions should be executed on incoming messages.
 *
 * @sealed
 */
export declare class Rule extends ComplexProperty {
    /**
     * The rule ID.
     */
    private ruleId;
    /**
     * The rule display name.
     */
    private displayName;
    /**
     * The rule priority.
     */
    private priority;
    /**
     * The rule status of enabled or not.
     */
    private isEnabled;
    /**
     * The rule status of is supported or not.
     */
    private isNotSupported;
    /**
     * The rule status of in error or not.
     */
    private isInError;
    /**
     * The rule conditions.
     */
    private conditions;
    /**
     * The rule actions.
     */
    private actions;
    /**
     * The rule exceptions.
     */
    private exceptions;
    /**
     * Gets or sets the Id of this rule.
     */
    get Id(): string;
    set Id(value: string);
    /**
     * Gets or sets the name of this rule as it should be displayed to the user.
     */
    get DisplayName(): string;
    set DisplayName(value: string);
    /**
     * Gets or sets the priority of this rule, which determines its execution order.
     */
    get Priority(): number;
    set Priority(value: number);
    /**
     * Gets or sets a value indicating whether this rule is enabled.
     */
    get IsEnabled(): boolean;
    set IsEnabled(value: boolean);
    /**
     * Gets a value indicating whether this rule can be modified via EWS. If IsNotSupported is true, the rule cannot be modified via EWS.
     */
    get IsNotSupported(): boolean;
    /**
     * Gets or sets a value indicating whether this rule has errors. A rule that is in error cannot be processed unless it is updated and the error is corrected.
     */
    get IsInError(): boolean;
    set IsInError(value: boolean);
    /**
     * Gets the conditions that determine whether or not this rule should be executed against incoming messages.
     */
    get Conditions(): RulePredicates;
    /**
     * Gets the actions that should be executed against incoming messages if the conditions evaluate as true.
     */
    get Actions(): RuleActions;
    /**
     * Gets the exceptions that determine if this rule should be skipped even if its conditions evaluate to true.
     */
    get Exceptions(): RulePredicates;
    /**
     * Initializes a new instance of the **Rule** class.
     */
    constructor();
}
