import { EmailAddressCollection } from "./EmailAddressCollection";
import { FolderId } from "./FolderId";
import { Importance } from "../Enumerations/Importance";
import { ItemId } from "./ItemId";
import { MobilePhone } from "../Misc/MobilePhone";
import { StringList } from "./StringList";
import { ComplexProperty } from "./ComplexProperty";
/**
 * Represents the set of actions available for a rule.
 *
 * @sealed
 */
export declare class RuleActions extends ComplexProperty {
    /**
     * SMS recipient address type.
     */
    private static MobileType;
    /**
     * The AssignCategories action.
     */
    private assignCategories;
    /**
     * The CopyToFolder action.
     */
    private copyToFolder;
    /**
     * The Delete action.
     */
    private delete;
    /**
     * The ForwardAsAttachmentToRecipients action.
     */
    private forwardAsAttachmentToRecipients;
    /**
     * The ForwardToRecipients action.
     */
    private forwardToRecipients;
    /**
     * The MarkImportance action.
     */
    private markImportance;
    /**
     * The MarkAsRead action.
     */
    private markAsRead;
    /**
     * The MoveToFolder action.
     */
    private moveToFolder;
    /**
     * The PermanentDelete action.
     */
    private permanentDelete;
    /**
     * The RedirectToRecipients action.
     */
    private redirectToRecipients;
    /**
     * The SendSMSAlertToRecipients action.
     */
    private sendSMSAlertToRecipients;
    /**
     * The ServerReplyWithMessage action.
     */
    private serverReplyWithMessage;
    /**
     * The StopProcessingRules action.
     */
    private stopProcessingRules;
    /**
     * Gets the categories that should be stamped on incoming messages.
     * To disable stamping incoming messages with categories, set AssignCategories to null.
     */
    get AssignCategories(): StringList;
    /**
     * Gets or sets the Id of the folder incoming messages should be copied to.
     * To disable copying incoming messages to a folder, set CopyToFolder to null.
     */
    get CopyToFolder(): FolderId;
    set CopyToFolder(value: FolderId);
    /**
     * Gets or sets a value indicating whether incoming messages should be automatically moved to the Deleted Items folder.
     */
    get Delete(): boolean;
    set Delete(value: boolean);
    /**
     * Gets the e-mail addresses to which incoming messages should be forwarded as attachments.
     * To disable forwarding incoming messages as attachments, empty the ForwardAsAttachmentToRecipients list.
     */
    get ForwardAsAttachmentToRecipients(): EmailAddressCollection;
    /**
     * Gets the e-mail addresses to which incoming messages should be forwarded.
     * To disable forwarding incoming messages, empty the ForwardToRecipients list.
     */
    get ForwardToRecipients(): EmailAddressCollection;
    /**
     * @Nullable Gets or sets the importance that should be stamped on incoming messages.
     * To disable the stamping of incoming messages with an importance, set MarkImportance to null.
     */
    get MarkImportance(): Importance;
    set MarkImportance(value: Importance);
    /**
     * Gets or sets a value indicating whether incoming messages should be marked as read.
     */
    get MarkAsRead(): boolean;
    set MarkAsRead(value: boolean);
    /**
     * Gets or sets the Id of the folder to which incoming messages should be moved.
     * To disable the moving of incoming messages to a folder, set CopyToFolder to null.
     */
    get MoveToFolder(): FolderId;
    set MoveToFolder(value: FolderId);
    /**
     * Gets or sets a value indicating whether incoming messages should be permanently deleted. When a message is permanently deleted, it is never saved into the recipient's mailbox. To delete a message after it has been saved into the recipient's mailbox, use the Delete action.
     */
    get PermanentDelete(): boolean;
    set PermanentDelete(value: boolean);
    /**
     * Gets the e-mail addresses to which incoming messages should be redirecteded.
     * To disable redirection of incoming messages, empty the RedirectToRecipients list. Unlike forwarded mail, redirected mail maintains the original sender and recipients.
     */
    get RedirectToRecipients(): EmailAddressCollection;
    /**
     * Gets the phone numbers to which an SMS alert should be sent.
     * To disable sending SMS alerts for incoming messages, empty the SendSMSAlertToRecipients list.
     */
    get SendSMSAlertToRecipients(): MobilePhone[];
    /**
     * Gets or sets the Id of the template message that should be sent as a reply to incoming messages.
     * To disable automatic replies, set ServerReplyWithMessage to null.
     */
    get ServerReplyWithMessage(): ItemId;
    set ServerReplyWithMessage(value: ItemId);
    /**
     * Gets or sets a value indicating whether subsequent rules should be evaluated.
     */
    get StopProcessingRules(): boolean;
    set StopProcessingRules(value: boolean);
    /**
     * Convert the SMS recipient list from EmailAddressCollection type to MobilePhone collection type.
     *
     * @param   {EmailAddressCollection}   emailCollection   Recipient list in EmailAddressCollection type.
     * @return  {MobilePhone[]}		A MobilePhone collection object containing all SMS recipient in MobilePhone type.
     */
    private static ConvertSMSRecipientsFromEmailAddressCollectionToMobilePhoneCollection;
    /**
     * Convert the SMS recipient list from MobilePhone collection type to EmailAddressCollection type.
     *
     * @param   {MobilePhone[]}   recipientCollection   Recipient list in a MobilePhone collection type.
     * @return  {EmailAddressCollection}		An EmailAddressCollection object containing recipients with "MOBILE" address type.
     */
    private static ConvertSMSRecipientsFromMobilePhoneCollectionToEmailAddressCollection;
}
