import { IEnumerable } from "../Interfaces/IEnumerable";
import { RuleError } from "./RuleError";
import { RuleOperation } from "./RuleOperation";
import { ComplexProperty } from "./ComplexProperty";
/**
 * Represents an error that occurred while processing a rule operation.
 *
 * @sealed
 */
export declare class RuleOperationError extends ComplexProperty implements IEnumerable<RuleError> {
    /**
     * Index of the operation mapping to the error.
     */
    private operationIndex;
    /**
     * RuleOperation object mapping to the error.
     */
    private operation;
    /**
     * RuleError Collection.
     */
    private ruleErrors;
    /**
     * Gets the operation that resulted in an error.
     */
    get Operation(): RuleOperation;
    /**
     * Gets the number of rule errors in the list.
     */
    get Count(): number;
    /**
     * Gets the rule error at the specified index.
     *
     * @param   {number}   index   The index of the rule error to get.
     * @return  {RuleError}	The rule error at the specified index.
     */
    _getItem(index: number): RuleError;
    /**
     *  Returns an enumerator that iterates through the collection. this case this.rules
     */
    GetEnumerator(): RuleError[];
}
