import { EmailAddressCollection } from "./EmailAddressCollection";
import { FlaggedForAction } from "../Enumerations/FlaggedForAction";
import { Importance } from "../Enumerations/Importance";
import { RulePredicateDateRange } from "./RulePredicateDateRange";
import { RulePredicateSizeRange } from "./RulePredicateSizeRange";
import { Sensitivity } from "../Enumerations/Sensitivity";
import { StringList } from "./StringList";
import { ComplexProperty } from "./ComplexProperty";
/**
 * Represents the set of conditions and exceptions available for a rule.
 *
 * @sealed
 */
export declare class RulePredicates extends ComplexProperty {
    /**
     * The HasCategories predicate.
     */
    private categories;
    /**
     * The ContainsBodyStrings predicate.
     */
    private containsBodyStrings;
    /**
     * The ContainsHeaderStrings predicate.
     */
    private containsHeaderStrings;
    /**
     * The ContainsRecipientStrings predicate.
     */
    private containsRecipientStrings;
    /**
     * The ContainsSenderStrings predicate.
     */
    private containsSenderStrings;
    /**
     * The ContainsSubjectOrBodyStrings predicate.
     */
    private containsSubjectOrBodyStrings;
    /**
     * The ContainsSubjectStrings predicate.
     */
    private containsSubjectStrings;
    /**
     * The FlaggedForAction predicate.
     */
    private flaggedForAction;
    /**
     * The FromAddresses predicate.
     */
    private fromAddresses;
    /**
     * The FromConnectedAccounts predicate.
     */
    private fromConnectedAccounts;
    /**
     * The HasAttachments predicate.
     */
    private hasAttachments;
    /**
     * The Importance predicate.
     */
    private importance;
    /**
     * The IsApprovalRequest predicate.
     */
    private isApprovalRequest;
    /**
     * The IsAutomaticForward predicate.
     */
    private isAutomaticForward;
    /**
     * The IsAutomaticReply predicate.
     */
    private isAutomaticReply;
    /**
     * The IsEncrypted predicate.
     */
    private isEncrypted;
    /**
     * The IsMeetingRequest predicate.
     */
    private isMeetingRequest;
    /**
     * The IsMeetingResponse predicate.
     */
    private isMeetingResponse;
    /**
     * The IsNDR predicate.
     */
    private isNonDeliveryReport;
    /**
     * The IsPermissionControlled predicate.
     */
    private isPermissionControlled;
    /**
     * The IsSigned predicate.
     */
    private isSigned;
    /**
     * The IsVoicemail predicate.
     */
    private isVoicemail;
    /**
     * The IsReadReceipt predicate.
     */
    private isReadReceipt;
    /**
     * The ItemClasses predicate.
     */
    private itemClasses;
    /**
     * The MessageClassifications predicate.
     */
    private messageClassifications;
    /**
     * The NotSentToMe predicate.
     */
    private notSentToMe;
    /**
     * The SentCcMe predicate.
     */
    private sentCcMe;
    /**
     * The SentOnlyToMe predicate.
     */
    private sentOnlyToMe;
    /**
     * The SentToAddresses predicate.
     */
    private sentToAddresses;
    /**
     * The SentToMe predicate.
     */
    private sentToMe;
    /**
     * The SentToOrCcMe predicate.
     */
    private sentToOrCcMe;
    /**
     * The Sensitivity predicate.
     */
    private sensitivity;
    /**
     * The WithinDateRange predicate.
     */
    private withinDateRange;
    /**
     * The WithinSizeRange predicate.
     */
    private withinSizeRange;
    /**
     * Gets the categories that an incoming message should be stamped with for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get Categories(): StringList;
    /**
     * Gets the strings that should appear in the body of incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get ContainsBodyStrings(): StringList;
    /**
     * Gets the strings that should appear in the headers of incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get ContainsHeaderStrings(): StringList;
    /**
     * Gets the strings that should appear in either the To or Cc fields of incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get ContainsRecipientStrings(): StringList;
    /**
     * Gets the strings that should appear in the From field of incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get ContainsSenderStrings(): StringList;
    /**
     * Gets the strings that should appear in either the body or the subject of incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get ContainsSubjectOrBodyStrings(): StringList;
    /**
     * Gets the strings that should appear in the subject of incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get ContainsSubjectStrings(): StringList;
    /**
     * @Nullable Gets or sets the flag for action value that should appear on incoming messages for the condition or execption to apply.
     * To disable this predicate, set it to null.
     */
    get FlaggedForAction(): FlaggedForAction;
    set FlaggedForAction(value: FlaggedForAction);
    /**
     * Gets the e-mail addresses of the senders of incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get FromAddresses(): EmailAddressCollection;
    /**
     * Gets or sets a value indicating whether incoming messages must have attachments for the condition or exception to apply.
     */
    get HasAttachments(): boolean;
    set HasAttachments(value: boolean);
    /**
     * @Nullable Gets or sets the importance that should be stamped on incoming messages for the condition or exception to apply.
     * To disable this predicate, set it to null.
     */
    get Importance(): Importance;
    set Importance(value: Importance);
    /**
     * Gets or sets a value indicating whether incoming messages must be approval requests for the condition or exception to apply.
     */
    get IsApprovalRequest(): boolean;
    set IsApprovalRequest(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be automatic forwards for the condition or exception to apply.
     */
    get IsAutomaticForward(): boolean;
    set IsAutomaticForward(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be automatic replies for the condition or exception to apply.
     */
    get IsAutomaticReply(): boolean;
    set IsAutomaticReply(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be S/MIME encrypted for the condition or exception to apply.
     */
    get IsEncrypted(): boolean;
    set IsEncrypted(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be meeting requests for the condition or exception to apply.
     */
    get IsMeetingRequest(): boolean;
    set IsMeetingRequest(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be meeting responses for the condition or exception to apply.
     */
    get IsMeetingResponse(): boolean;
    set IsMeetingResponse(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be non-delivery reports (NDR) for the condition or exception to apply.
     */
    get IsNonDeliveryReport(): boolean;
    set IsNonDeliveryReport(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be permission controlled (RMS protected) for the condition or exception to apply.
     */
    get IsPermissionControlled(): boolean;
    set IsPermissionControlled(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be S/MIME signed for the condition or exception to apply.
     */
    get IsSigned(): boolean;
    set IsSigned(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be voice mails for the condition or exception to apply.
     */
    get IsVoicemail(): boolean;
    set IsVoicemail(value: boolean);
    /**
     * Gets or sets a value indicating whether incoming messages must be read receipts for the condition or exception to apply.
     */
    get IsReadReceipt(): boolean;
    set IsReadReceipt(value: boolean);
    /**
     * Gets the e-mail account names from which incoming messages must have been aggregated for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get FromConnectedAccounts(): StringList;
    /**
     * Gets the item classes that must be stamped on incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get ItemClasses(): StringList;
    /**
     * Gets the message classifications that must be stamped on incoming messages for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get MessageClassifications(): StringList;
    /**
     * Gets or sets a value indicating whether the owner of the mailbox must NOT be a To recipient of the incoming messages for the condition or exception to apply.
     */
    get NotSentToMe(): boolean;
    set NotSentToMe(value: boolean);
    /**
     * Gets or sets a value indicating whether the owner of the mailbox must be a Cc recipient of incoming messages for the condition or exception to apply.
     */
    get SentCcMe(): boolean;
    set SentCcMe(value: boolean);
    /**
     * Gets or sets a value indicating whether the owner of the mailbox must be the only To recipient of incoming messages for the condition or exception to apply.
     */
    get SentOnlyToMe(): boolean;
    set SentOnlyToMe(value: boolean);
    /**
     * Gets the e-mail addresses incoming messages must have been sent to for the condition or exception to apply.
     * To disable this predicate, empty the list.
     */
    get SentToAddresses(): EmailAddressCollection;
    /**
     * Gets or sets a value indicating whether the owner of the mailbox must be a To recipient of incoming messages for the condition or exception to apply.
     */
    get SentToMe(): boolean;
    set SentToMe(value: boolean);
    /**
     * Gets or sets a value indicating whether the owner of the mailbox must be either a To or Cc recipient of incoming messages for the condition or exception to apply.
     */
    get SentToOrCcMe(): boolean;
    set SentToOrCcMe(value: boolean);
    /**
     * @Nullable Gets or sets the sensitivity that must be stamped on incoming messages for the condition or exception to apply.
     * To disable this predicate, set it to null.
     */
    get Sensitivity(): Sensitivity;
    set Sensitivity(value: Sensitivity);
    /**
     * Gets the date range within which incoming messages must have been received for the condition or exception to apply.
     * To disable this predicate, set both its Start and End properties to null.
     */
    get WithinDateRange(): RulePredicateDateRange;
    /**
     * Gets the minimum and maximum sizes incoming messages must have for the condition or exception to apply.
     * To disable this predicate, set both its MinimumSize and MaximumSize properties to null.
     */
    get WithinSizeRange(): RulePredicateSizeRange;
}
