import { IEnumerable } from "../../Interfaces/IEnumerable";
import { ServiceResponse } from "./ServiceResponse";
import { ServiceResult } from "../../Enumerations/ServiceResult";
/**
 * Represents a strogly typed list of service responses.
 * @sealed
 * @typeparam   {TResponse}     The type of response stored in the list.
 */
export declare class ServiceResponseCollection<TResponse extends ServiceResponse> implements IEnumerable<TResponse> {
    private responses;
    private overallResult;
    /**
     * Gets the total number of responses in the list.
     */
    get Count(): number;
    get Responses(): TResponse[];
    /**
     * Gets a value indicating the overall result of the request that generated this response collection.
     * If all of the responses have their Result property set to Success, OverallResult returns Success.
     * If at least one response has its Result property set to Warning and all other responses have their Result property set to Success, OverallResult returns Warning.
     * If at least one response has a its Result set to Error, OverallResult returns Error.
     */
    get OverallResult(): ServiceResult;
    /**
     * Gets an enumerator that iterates through the elements of the collection.
     *
     * @return  {TResponse[]}      An IEnumerator for the collection.
     */
    GetEnumerator(): TResponse[];
    /**
     * Gets the response at the specified index.
     *
     * @param   {number}        index   The zero-based index of the response to get.
     * @return  {TResponse}     The response at the specified index.
     */
    __thisIndexer(index: number): TResponse;
}
