import { CompleteName } from "../../../ComplexProperties/CompleteName";
import { ContactSource } from "../../../Enumerations/ContactSource";
import { DateTime } from "../../../DateTime";
import { EmailAddress } from "../../../ComplexProperties/EmailAddress";
import { EmailAddressCollection } from "../../../ComplexProperties/EmailAddressCollection";
import { EmailAddressDictionary } from "../../../ComplexProperties/EmailAddressDictionary";
import { ExchangeService } from "../../ExchangeService";
import { FileAsMapping } from "../../../Enumerations/FileAsMapping";
import { FileAttachment } from "../../../ComplexProperties/FileAttachment";
import { ImAddressDictionary } from "../../../ComplexProperties/ImAddressDictionary";
import { ItemId } from "../../../ComplexProperties/ItemId";
import { PhoneNumberDictionary } from "../../../ComplexProperties/PhoneNumberDictionary";
import { PhysicalAddressDictionary } from "../../../ComplexProperties/PhysicalAddressDictionary";
import { PhysicalAddressIndex } from "../../../Enumerations/PhysicalAddressIndex";
import { PropertySet } from "../../PropertySet";
import { StringList } from "../../../ComplexProperties/StringList";
import { Item } from "./Item";
/**
 * Represents a **contact**. Properties available on contacts are defined in the *ContactSchema* class.
 *
 */
export declare class Contact extends Item {
    /** required to check [Attachable] attribute, AttachmentCollection.AddItemAttachment<TItem>() checks for non inherited [Attachable] attribute. */
    static get Attachable(): boolean;
    private static ContactPictureName;
    /**
     * Gets or set the name under which this contact is filed as. FileAs can be manually set or can be automatically calculated based on the value of the FileAsMapping property.
     *
     */
    get FileAs(): string;
    set FileAs(value: string);
    /**
     * Gets or sets a value indicating how the FileAs property should be automatically calculated.
     *
     */
    get FileAsMapping(): FileAsMapping;
    set FileAsMapping(value: FileAsMapping);
    /**
     * Gets or sets the display name of the contact.
     *
     */
    get DisplayName(): string;
    set DisplayName(value: string);
    /**
     * Gets or sets the given name of the contact.
     *
     */
    get GivenName(): string;
    set GivenName(value: string);
    /**
     * Gets or sets the initials of the contact.
     *
     */
    get Initials(): string;
    set Initials(value: string);
    /**
     * Gets or sets the middle mame of the contact.
     *
     */
    get MiddleName(): string;
    set MiddleName(value: string);
    /**
     * Gets or sets the nick name of the contact.
     *
     */
    get NickName(): string;
    set NickName(value: string);
    /**
     * Gets the complete name of the contact.
     *
     */
    get CompleteName(): CompleteName;
    /**
     * Gets or sets the compnay name of the contact.
     *
     */
    get CompanyName(): string;
    set CompanyName(value: string);
    /**
     * Gets an indexed list of e-mail addresses for the contact. For example, to set the first e-mail address,
     * use the following syntax: EmailAddresses[EmailAddressKey.EmailAddress1] = "john.doe@contoso.com"
     *
     */
    get EmailAddresses(): EmailAddressDictionary;
    /**
     * Gets an indexed list of physical addresses for the contact. For example, to set the business address,
     * use the following syntax: PhysicalAddresses[PhysicalAddressKey.Business] = new PhysicalAddressEntry()
     *
     */
    get PhysicalAddresses(): PhysicalAddressDictionary;
    /**
     * Gets an indexed list of phone numbers for the contact. For example, to set the home phone number,
     * use the following syntax: PhoneNumbers[PhoneNumberKey.HomePhone] = "phone number"
     *
     */
    get PhoneNumbers(): PhoneNumberDictionary;
    /**
     * Gets or sets the contact's assistant name.
     *
     */
    get AssistantName(): string;
    set AssistantName(value: string);
    /**
     * Gets or sets the birthday of the contact.
     *
     */
    get Birthday(): DateTime;
    set Birthday(value: DateTime);
    /**
     * Gets or sets the business home page of the contact.
     *
     */
    get BusinessHomePage(): string;
    set BusinessHomePage(value: string);
    /**
     * Gets or sets a list of children for the contact.
     *
     */
    get Children(): StringList;
    set Children(value: StringList);
    /**
     * Gets or sets a list of companies for the contact.
     *
     */
    get Companies(): StringList;
    set Companies(value: StringList);
    /**
     * Gets the source of the contact.
     *
     */
    get ContactSource(): ContactSource;
    /**
     * Gets or sets the department of the contact.
     *
     */
    get Department(): string;
    set Department(value: string);
    /**
     * Gets or sets the generation of the contact.
     *
     */
    get Generation(): string;
    set Generation(value: string);
    /**
     * Gets an indexed list of Instant Messaging addresses for the contact.
     * For example, to set the first IM address, use the following syntax: ImAddresses[ImAddressKey.ImAddress1] = "john.doe@contoso.com"
     *
     */
    get ImAddresses(): ImAddressDictionary;
    /**
     * Gets or sets the contact's job title.
     *
     */
    get JobTitle(): string;
    set JobTitle(value: string);
    /**
     * Gets or sets the name of the contact's manager.
     *
     */
    get Manager(): string;
    set Manager(value: string);
    /**
     * Gets or sets the mileage for the contact.
     *
     */
    get Mileage(): string;
    set Mileage(value: string);
    /**
     * Gets or sets the location of the contact's office.
     *
     */
    get OfficeLocation(): string;
    set OfficeLocation(value: string);
    /**
     * Gets or sets the index of the contact's postal address. When set, PostalAddressIndex refers to an entry in the PhysicalAddresses indexed list.
     *
     */
    get PostalAddressIndex(): PhysicalAddressIndex;
    set PostalAddressIndex(value: PhysicalAddressIndex);
    /**
     * Gets or sets the contact's profession.
     *
     */
    get Profession(): string;
    set Profession(value: string);
    /**
     * Gets or sets the name of the contact's spouse.
     *
     */
    get SpouseName(): string;
    set SpouseName(value: string);
    /**
     * Gets or sets the surname of the contact.
     *
     */
    get Surname(): string;
    set Surname(value: string);
    /**
     * Gets or sets the date of the contact's wedding anniversary.
     *
     */
    get WeddingAnniversary(): DateTime;
    set WeddingAnniversary(value: DateTime);
    /**
     * Gets a value indicating whether this contact has a picture associated with it.
     *
     */
    get HasPicture(): boolean;
    /**
     * Gets the full phonetic name from the directory
     *
     */
    get PhoneticFullName(): string;
    /**
     * Gets the phonetic first name from the directory
     *
     */
    get PhoneticFirstName(): string;
    /**
     * Gets the phonetic last name from the directory
     *
     */
    get PhoneticLastName(): string;
    /**
     * Gets the Alias from the directory
     *
     */
    get Alias(): string;
    /**
     * Get the Notes from the directory
     *
     */
    get Notes(): string;
    /**
     * Gets the Photo from the directory **Unstable: needs testing**
     *
     */
    get DirectoryPhoto(): number[];
    /**
     * Gets the User SMIME certificate from the directory **Unstable: needs testing**
     * //ref: cant use bytearray, using base64 decoded string instead -  number[][]
     *
     */
    get UserSMIMECertificate(): string[];
    /**
     * Gets the MSExchange certificate from the directory **Unstable: needs testing**
     * //ref: cant use bytearray, using base64 decoded string instead -  number[][]
     *
     */
    get MSExchangeCertificate(): string[];
    /**
     * Gets the DirectoryID as Guid or DN string
     *
     */
    get DirectoryId(): string;
    /**
     * Gets the manager mailbox information
     *
     */
    get ManagerMailbox(): EmailAddress;
    /**
     * Get the direct reports mailbox information
     *
     */
    get DirectReports(): EmailAddressCollection;
    /**
     * Initializes an unsaved local instance of . To bind to an existing contact, use Contact.Bind() instead.
     *
     * @param   {ExchangeService}   service   The ExchangeService object to which the contact will be bound.
     */
    constructor(service: ExchangeService);
    /**
     * Binds to an existing contact and loads the specified set of properties.
     * Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service         The service to use to bind to the contact.
     * @param   {ItemId}            id              The Id of the contact to bind to.
     * @return  {Promise<Contact>}                 A Contact instance representing the contact corresponding to the specified Id :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId): Promise<Contact>;
    /**
     * Binds to an existing contact and loads the specified set of properties.
     * Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service         The service to use to bind to the contact.
     * @param   {ItemId}            id              The Id of the contact to bind to.
     * @param   {PropertySet}       propertySet     The set of properties to load.
     * @return  {Promise<Contact>}                 A Contact instance representing the contact corresponding to the specified Id :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId, propertySet: PropertySet): Promise<Contact>;
    /**
     * Retrieves the file attachment that holds the contact's picture. **Unstable: needs testing**
     *
     * @return  {FileAttachment}      The file attachment that holds the contact's picture.
     */
    GetContactPictureAttachment(): FileAttachment;
    /**
     * Removes the picture from local attachment collection.     *
     */
    private InternalRemoveContactPicture;
    /**
     * Removes the contact's picture.     *
     */
    RemoveContactPicture(): void;
    /**
     * Sets the contact's picture using the base64 content of file.
     *
     * @param   {string}    base64Content       base64 content of picture attachment.
     * @param   {string}    attachmentName      name of the picture attachment.
     *
     */
    SetContactPicture(base64Content: string, attachmentName: string): void;
}
