import { ArchiveTag } from "../../../ComplexProperties/ArchiveTag";
import { AttachmentCollection } from "../../../ComplexProperties/AttachmentCollection";
import { ConflictResolutionMode } from "../../../Enumerations/ConflictResolutionMode";
import { ConversationId } from "../../../ComplexProperties/ConversationId";
import { DateTime } from "../../../DateTime";
import { DeleteMode } from "../../../Enumerations/DeleteMode";
import { EffectiveRights } from "../../../Enumerations/EffectiveRights";
import { EntityExtractionResult } from "../../../ComplexProperties/EntityExtractionResult";
import { ExchangeService } from "../../ExchangeService";
import { ExtendedPropertyCollection } from "../../../ComplexProperties/ExtendedPropertyCollection";
import { ExtendedPropertyDefinition } from "../../../PropertyDefinitions/ExtendedPropertyDefinition";
import { Flag } from "../../../ComplexProperties/Flag";
import { FolderId } from "../../../ComplexProperties/FolderId";
import { IconIndex } from "../../../Enumerations/IconIndex";
import { Importance } from "../../../Enumerations/Importance";
import { InternetMessageHeaderCollection } from "../../../ComplexProperties/InternetMessageHeaderCollection";
import { ItemId } from "../../../ComplexProperties/ItemId";
import { MessageBody } from "../../../ComplexProperties/MessageBody";
import { MimeContent } from "../../../ComplexProperties/MimeContent";
import { NormalizedBody } from "../../../ComplexProperties/NormalizedBody";
import { PolicyTag } from "../../../ComplexProperties/PolicyTag";
import { PropertyDefinition } from "../../../PropertyDefinitions/PropertyDefinition";
import { PropertySet } from "../../PropertySet";
import { ResponseActions } from "../../../Enumerations/ResponseActions";
import { Sensitivity } from "../../../Enumerations/Sensitivity";
import { StringList } from "../../../ComplexProperties/StringList";
import { TextBody } from "../../../ComplexProperties/TextBody";
import { UniqueBody } from "../../../ComplexProperties/UniqueBody";
import { WellKnownFolderName } from "../../../Enumerations/WellKnownFolderName";
import { ServiceObject } from "../ServiceObject";
/**
 * Represents a generic **Item**. Properties available on items are defined in the *ItemSchema* class.
 *
 */
export declare class Item extends ServiceObject {
    /** required to check [Attachable] attribute, AttachmentCollection.AddItemAttachment<TItem>() checks for non inherited [Attachable] attribute. */
    static get Attachable(): boolean;
    private parentAttachment;
    /**
     * Gets a value indicating whether the item is an attachment.
     *
     */
    get IsAttachment(): boolean;
    /**
     * Gets a value indicating whether this object is a real store item, or if it's a local object that has yet to be saved.
     *
     */
    get IsNew(): boolean;
    /**
     * Gets the Id of this item.
     *
     */
    get Id(): ItemId;
    /**
     * Get or sets the MIME content of this item.
     *
     */
    get MimeContent(): MimeContent;
    set MimeContent(value: MimeContent);
    /**
     * Gets the Id of the parent folder of this item.
     *
     */
    get ParentFolderId(): FolderId;
    /**
     * Gets or sets the sensitivity of this item.
     *
     */
    get Sensitivity(): Sensitivity;
    set Sensitivity(value: Sensitivity);
    /**
     * Gets a list of the attachments to this item.
     *
     */
    get Attachments(): AttachmentCollection;
    /**
     * Gets the time when this item was received.
     *
     */
    get DateTimeReceived(): DateTime;
    /**
     * Gets the size of this item.
     *
     */
    get Size(): number;
    /**
     * Gets or sets the list of categories associated with this item.
     *
     */
    get Categories(): StringList;
    set Categories(value: StringList);
    /**
     * Gets or sets the culture associated with this item.
     *
     */
    get Culture(): string;
    set Culture(value: string);
    /**
     * Gets or sets the importance of this item.
     *
     */
    get Importance(): Importance;
    set Importance(value: Importance);
    /**
     * Gets or sets the In-Reply-To reference of this item.
     *
     */
    get InReplyTo(): string;
    set InReplyTo(value: string);
    /**
     * Gets a value indicating whether the message has been submitted to be sent.
     *
     */
    get IsSubmitted(): boolean;
    /**
     * Gets a value indicating whether this is an associated item.
     *
     */
    get IsAssociated(): boolean;
    /**
     * Gets a value indicating whether the item is is a draft. An item is a draft when it has not yet been sent.
     *
     */
    get IsDraft(): boolean;
    /**
     * Gets a value indicating whether the item has been sent by the current authenticated user.
     *
     */
    get IsFromMe(): boolean;
    /**
     * Gets a value indicating whether the item is a resend of another item.
     *
     */
    get IsResend(): boolean;
    /**
     * Gets a value indicating whether the item has been modified since it was created.
     *
     */
    get IsUnmodified(): boolean;
    /**
     * Gets a list of Internet headers for this item.
     *
     */
    get InternetMessageHeaders(): InternetMessageHeaderCollection;
    /**
     * Gets the date and time this item was sent.
     *
     */
    get DateTimeSent(): DateTime;
    /**
     * Gets the date and time this item was created.
     *
     */
    get DateTimeCreated(): DateTime;
    /**
     * Gets a value indicating which response actions are allowed on this item. Examples of response actions are Reply and Forward.
     *
     */
    get AllowedResponseActions(): ResponseActions;
    /**
     * Gets or sets the date and time when the reminder is due for this item.
     *
     */
    get ReminderDueBy(): DateTime;
    set ReminderDueBy(value: DateTime);
    /**
     * Gets or sets a value indicating whether a reminder is set for this item.
     *
     */
    get IsReminderSet(): boolean;
    set IsReminderSet(value: boolean);
    /**
     * Gets or sets the number of minutes before the start of this item when the reminder should be triggered.
     *
     */
    get ReminderMinutesBeforeStart(): number;
    set ReminderMinutesBeforeStart(value: number);
    /**
     * Gets a text summarizing the Cc receipients of this item.
     *
     */
    get DisplayCc(): string;
    /**
     * Gets a text summarizing the To recipients of this item.
     *
     */
    get DisplayTo(): string;
    /**
     * Gets a value indicating whether the item has attachments.
     *
     */
    get HasAttachments(): boolean;
    /**
     * Gets or sets the body of this item.
     *
     */
    get Body(): MessageBody;
    set Body(value: MessageBody);
    /**
     * Gets or sets the custom class name of this item.
     *
     */
    get ItemClass(): string;
    set ItemClass(value: string);
    /**
     * Gets or sets the subject of this item.
     *
     */
    get Subject(): string;
    set Subject(value: string);
    /**
     * Gets the query string that should be appended to the Exchange Web client URL to open this item using the appropriate read form in a web browser.
     *
     */
    get WebClientReadFormQueryString(): string;
    /**
     * Gets the query string that should be appended to the Exchange Web client URL to open this item using the appropriate edit form in a web browser.
     *
     */
    get WebClientEditFormQueryString(): string;
    /**
     * Gets a list of extended properties defined on this item.
     *
     */
    get ExtendedProperties(): ExtendedPropertyCollection;
    /**
     * Gets a value indicating the effective rights the current authenticated user has on this item.
     *
     */
    get EffectiveRights(): EffectiveRights;
    /**
     * Gets the name of the user who last modified this item.
     *
     */
    get LastModifiedName(): string;
    /**
     * Gets the date and time this item was last modified.
     *
     */
    get LastModifiedTime(): DateTime;
    /**
     * Gets the Id of the conversation this item is part of.
     *
     */
    get ConversationId(): ConversationId;
    /**
     * Gets the body part that is unique to the conversation this item is part of.
     *
     */
    get UniqueBody(): UniqueBody;
    /**
     * Gets the store entry id.
     *
     */
    get StoreEntryId(): number[];
    /**
     * Gets the item instance key.
     *
     */
    get InstanceKey(): number[];
    /**
     * Get or set the Flag value for this item.
     *
     */
    get Flag(): Flag;
    set Flag(value: Flag);
    /**
     * Gets the normalized body of the item.
     *
     */
    get NormalizedBody(): NormalizedBody;
    /**
     * Gets the EntityExtractionResult of the item.
     *
     */
    get EntityExtractionResult(): EntityExtractionResult;
    /**
     * Gets or sets the policy tag.
     *
     */
    get PolicyTag(): PolicyTag;
    set PolicyTag(value: PolicyTag);
    /**
     * Gets or sets the archive tag.
     *
     */
    get ArchiveTag(): ArchiveTag;
    set ArchiveTag(value: ArchiveTag);
    /**
     * Gets the retention date.
     *
     */
    get RetentionDate(): DateTime;
    /**
     * Gets the item Preview.
     *
     */
    get Preview(): string;
    /**
     * Gets the text body of the item.
     *
     */
    get TextBody(): TextBody;
    /**
     * Gets the icon index.
     *
     */
    get IconIndex(): IconIndex;
    /**
     * Binds to an existing item, whatever its actual type is, and loads the specified set of properties. Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service         The service to use to bind to the item.
     * @param   {ItemId}            id              The Id of the item to bind to.
     * @return  {Promise<Item>}                    An Item instance representing the item corresponding to the specified Id :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId): Promise<Item>;
    /**
     * Binds to an existing item, whatever its actual type is, and loads the specified set of properties. Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service         The service to use to bind to the item.
     * @param   {ItemId}            id              The Id of the item to bind to.
     * @param   {PropertySet}       propertySet     The set of properties to load.
     * @return  {Promise<Item>}                    An Item instance representing the item corresponding to the specified Id :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId, propertySet: PropertySet): Promise<Item>;
    /**
     * Creates a copy of this item in the specified folder. Calling this method results in a call to EWS.
     *
     * Copy returns null if the copy operation is across two mailboxes or between a mailbox and a public folder.
     *
     * @param   {WellKnownFolderName}   destinationFolderName   The name of the folder in which to create a copy of this item.
     * @return  {Promise<Item>}                                The copy of this item :Promise.
     */
    Copy(destinationFolderName: WellKnownFolderName): Promise<Item>;
    /**
     * Creates a copy of this item in the specified folder. Calling this method results in a call to EWS.
     *
     *  Copy returns null if the copy operation is across two mailboxes or between a mailbox and a public folder.
     *
     * @param   {FolderId}          destinationFolderId   The Id of the folder in which to create a copy of this item.
     * @return  {Promise<Item>}                          The copy of this item :Promise.
     */
    Copy(destinationFolderId: FolderId): Promise<Item>;
    /**
     * Deletes the item. Calling this method results in a call to EWS.
     *
     * @param   {DeleteMode}   deleteMode             The deletion mode.
     */
    Delete(deleteMode: DeleteMode): Promise<void>;
    /**
     * Deletes the item. Calling this method results in a call to EWS.
     *
     * @param   {DeleteMode}   deleteMode             The deletion mode.
     * @param   {boolean}   suppressReadReceipts   Whether to suppress read receipts
     */
    Delete(deleteMode: DeleteMode, suppressReadReceipts: boolean): Promise<void>;
    /**
     * @inrtnal The property definition for the Id of this object.
     *
     * @return  {PropertyDefinition}      A PropertyDefinition instance.
     */
    GetIdPropertyDefinition(): PropertyDefinition;
    /**
     * Gets a value indicating whether a time zone SOAP header should be emitted in a CreateItem or UpdateItem request so this item can be property saved or updated.
     *
     * @param   {boolean}   isUpdateOperation   Indicates whether the operation being petrformed is an update operation.
     * @return  {boolean}                       true if a time zone SOAP header should be emitted; otherwise, false.
     */
    GetIsTimeZoneHeaderRequired(isUpdateOperation: boolean): boolean;
    /**
     * Moves this item to a the specified folder. Calling this method results in a call to EWS.
     *
     * Move returns null if the move operation is across two mailboxes or between a mailbox and a public folder.
     *
     * @param   {FolderId}   destinationFolderId    The Id of the folder to which to move this item.
     * @return  {Promise<Item>}                    The moved copy of this item :Promise.
     */
    Move(destinationFolderId: FolderId): Promise<Item>;
    /**
     * Moves this item to a the specified folder. Calling this method results in a call to EWS.
     *
     * Move returns null if the move operation is across two mailboxes or between a mailbox and a public folder.
     *
     * @param   {WellKnownFolderName}   destinationFolderName   The name of the folder to which to move this item.
     * @return  {Promise<Item>}        The moved copy of this item :Promise.
     */
    Move(destinationFolderName: WellKnownFolderName): Promise<Item>;
    /**
     * Removes an extended property.
     *
     * @param   {ExtendedPropertyDefinition}    extendedPropertyDefinition   The extended property definition.
     * @return  {boolean}                       True if property was removed.
     */
    RemoveExtendedProperty(extendedPropertyDefinition: ExtendedPropertyDefinition): boolean;
    /**
     * Saves this item in the default folder based on the item's type (for example, an e-mail message is saved to the Drafts folder).
     * Calling this method results in at least one call to EWS. Mutliple calls to EWS might be made if attachments have been added.
     *
     */
    Save(): Promise<void>;
    /**
     * Saves this item in a specific folder. Calling this method results in at least one call to EWS.
     * Mutliple calls to EWS might be made if attachments have been added.
     *
     * @param   {WellKnownFolderName}   parentFolderName   The name of the folder in which to save this item.
     */
    Save(parentFolderName?: WellKnownFolderName): Promise<void>;
    /**
     * Saves this item in a specific folder. Calling this method results in at least one call to EWS.
     * Mutliple calls to EWS might be made if attachments have been added.
     *
     * @param   {FolderId}   parentFolderId   The Id of the folder in which to save this item.
     */
    Save(parentFolderId?: FolderId): Promise<void>;
    /**
     * Sets the extended property.
     *
     * @param   {ExtendedPropertyDefinition}    extendedPropertyDefinition   The extended property definition.
     * @param   {value}                         value                        The value.
     */
    SetExtendedProperty(extendedPropertyDefinition: ExtendedPropertyDefinition, value: any): void;
    /**
     * Throws exception if this is attachment.
     *
     */
    ThrowIfThisIsAttachment(): void;
    /**
     * Applies the local changes that have been made to this item. Calling this method results in at least one call to EWS.
     * Mutliple calls to EWS might be made if attachments have been added or removed.
     *
     * @param   {ConflictResolutionMode}   conflictResolutionMode   The conflict resolution mode.
     */
    Update(conflictResolutionMode: ConflictResolutionMode): Promise<void>;
    /**
     * Applies the local changes that have been made to this item. Calling this method results in at least one call to EWS.
     * Mutliple calls to EWS might be made if attachments have been added or removed.
     *
     * @param   {ConflictResolutionMode}   conflictResolutionMode   The conflict resolution mode.
     * @param   {boolean}   suppressReadReceipts     Whether to suppress read receipts
     */
    Update(conflictResolutionMode: ConflictResolutionMode, suppressReadReceipts: boolean): Promise<void>;
}
