import { DateTime } from "../../../DateTime";
import { ExchangeService } from "../../ExchangeService";
import { ItemId } from "../../../ComplexProperties/ItemId";
import { MeetingResponseType } from "../../../Enumerations/MeetingResponseType";
import { PropertySet } from "../../PropertySet";
import { EmailMessage } from "./EmailMessage";
/**
 * Represents a meeting-related message. Properties available on meeting messages are defined in the MeetingMessageSchema class.
 */
export declare class MeetingMessage extends EmailMessage {
    /**
     * Gets the Id of the appointment associated with the meeting message.
     */
    get AssociatedAppointmentId(): ItemId;
    /**
     * Gets a value indicating whether the meeting message is delegated.
     */
    get IsDelegated(): boolean;
    /**
     * Gets a value indicating whether the meeting message is out of date.
     */
    get IsOutOfDate(): boolean;
    /**
     * Gets a value indicating whether the meeting message has been processed by Exchange (i.e. Exchange has noted the arrival of a meeting request and has created the associated meeting item in the calendar).
     */
    get HasBeenProcessed(): boolean;
    /**
     * Gets the isorganizer property for this meeting
     *
     * @Nullable
     */
    get IsOrganizer(): boolean;
    /**
     * Gets the type of response the meeting message represents.
     */
    get ResponseType(): MeetingResponseType;
    /**
     * Gets the ICalendar Uid.
     */
    get ICalUid(): string;
    /**
     * Gets the ICalendar RecurrenceId.
     *
     * @Nullable
     */
    get ICalRecurrenceId(): DateTime;
    /**
     * Gets the ICalendar DateTimeStamp.
     */
    get ICalDateTimeStamp(): DateTime;
    /**
     * Binds to an existing meeting message and loads the specified set of properties.
     * Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service       The service to use to bind to the meeting message.
     * @param   {ItemId}            id            The Id of the meeting message to bind to.
     * @param   {PropertySet}       propertySet   The set of properties to load.
     * @return  {Promise<MeetingMessage>}  A MeetingMessage instance representing the meeting message corresponding to the specified Id    :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId, propertySet: PropertySet): Promise<MeetingMessage>;
    /**
     * Binds to an existing meeting message and loads its first class properties.
     * Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service       The service to use to bind to the meeting message.
     * @param   {ItemId}            id            The Id of the meeting message to bind to.
     * @param   {PropertySet}       propertySet   The set of properties to load.
     * @return  {Promise<MeetingMessage>}  A MeetingMessage instance representing the meeting message corresponding to the specified Id    :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId): Promise<MeetingMessage>;
}
