import { DateTime } from "../../../DateTime";
import { EnhancedLocation } from "../../../ComplexProperties/EnhancedLocation";
import { ExchangeService } from "../../ExchangeService";
import { ItemId } from "../../../ComplexProperties/ItemId";
import { PropertySet } from "../../PropertySet";
import { Recurrence } from "../../../ComplexProperties/Recurrence/Patterns/Recurrence";
import { MeetingMessage } from "./MeetingMessage";
/**
 * Represents a response to a meeting request. Properties available on meeting messages are defined in the MeetingMessageSchema class.
 */
export declare class MeetingResponse extends MeetingMessage {
    /**
     * Gets the start time of the appointment.
     */
    get Start(): DateTime;
    /**
     * Gets the end time of the appointment.
     */
    get End(): DateTime;
    /**
     * Gets the location of this appointment.
     */
    get Location(): string;
    /**
     * Gets the recurrence pattern for this meeting request.
     */
    get Recurrence(): Recurrence;
    /**
     * Gets the proposed start time of the appointment.
     */
    get ProposedStart(): DateTime;
    /**
     * Gets the proposed end time of the appointment.
     */
    get ProposedEnd(): DateTime;
    /**
     * Gets the Enhanced location object.
     */
    get EnhancedLocation(): EnhancedLocation;
    /**
     * Binds to an existing meeting response and loads the specified set of properties. Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service       The service to use to bind to the meeting response.
     * @param   {ItemId}            id            The Id of the meeting response to bind to.
     * @param   {PropertySet}       propertySet   The set of properties to load.
     * @return  {Promise<MeetingResponse>}       A MeetingResponse instance representing the meeting response corresponding to the specified Id    :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId, propertySet: PropertySet): Promise<MeetingResponse>;
    /**
     * Binds to an existing meeting response and loads its first class properties. Calling this method results in a call to EWS.
     *
     * @param   {ExchangeService}   service       The service to use to bind to the meeting response.
     * @param   {ItemId}            id            The Id of the meeting response to bind to.
     * @return  {Promise<MeetingResponse>}       A MeetingResponse instance representing the meeting response corresponding to the specified Id    :Promise.
     */
    static Bind(service: ExchangeService, id: ItemId): Promise<MeetingResponse>;
}
