import { AttachmentCollection } from "../../../ComplexProperties/AttachmentCollection";
import { EmailAddress } from "../../../ComplexProperties/EmailAddress";
import { EmailAddressCollection } from "../../../ComplexProperties/EmailAddressCollection";
import { EmailMessage } from "../Items/EmailMessage";
import { InternetMessageHeaderCollection } from "../../../ComplexProperties/InternetMessageHeaderCollection";
import { MessageBody } from "../../../ComplexProperties/MessageBody";
import { Sensitivity } from "../../../Enumerations/Sensitivity";
import { CalendarResponseMessageBase } from "./CalendarResponseMessageBase";
/**
 * Represents the base class for accept, tentatively accept and decline response messages.
 *
 * @typeparam   {TMessage}     The type of message that is created when this response message is saved.
 */
export declare abstract class CalendarResponseMessage<TMessage extends EmailMessage> extends CalendarResponseMessageBase<TMessage> {
    /**
     * Gets or sets the body of the response.
     */
    get Body(): MessageBody;
    set Body(value: MessageBody);
    /**
     * Gets a list of recipients the response will be sent to.
     */
    get ToRecipients(): EmailAddressCollection;
    /**
     * Gets a list of recipients the response will be sent to as Cc.
     */
    get CcRecipients(): EmailAddressCollection;
    /**
     * Gets a list of recipients this response will be sent to as Bcc.
     */
    get BccRecipients(): EmailAddressCollection;
    get ItemClass(): string;
    set ItemClass(value: string);
    /**
     * Gets or sets the sensitivity of this response.
     */
    get Sensitivity(): Sensitivity;
    set Sensitivity(value: Sensitivity);
    /**
     * Gets a list of attachments to this response.
     */
    get Attachments(): AttachmentCollection;
    get InternetMessageHeaders(): InternetMessageHeaderCollection;
    /**
     * Gets or sets the sender of this response.
     */
    get Sender(): EmailAddress;
    set Sender(value: EmailAddress);
}
