import { FolderId } from "../../../ComplexProperties/FolderId";
import { MessageBody } from "../../../ComplexProperties/MessageBody";
import { PostItem } from "../Items/PostItem";
import { WellKnownFolderName } from "../../../Enumerations/WellKnownFolderName";
import { ServiceObject } from "../ServiceObject";
/**
 * Represents a reply to a post item.
 *
 * @sealed
 */
export declare class PostReply extends ServiceObject {
    private referenceItem;
    /**
     * Gets or sets the subject of the post reply.
     */
    get Subject(): string;
    set Subject(value: string);
    /**
     * Gets or sets the body of the post reply.
     */
    get Body(): MessageBody;
    set Body(value: MessageBody);
    /**
     * Gets or sets the body prefix that should be prepended to the original post item's body.
     */
    get BodyPrefix(): MessageBody;
    set BodyPrefix(value: MessageBody);
    /**
     * Saves the post reply in the same folder as the original post item. Calling this method results in a call to EWS.
     *
     * @return  {Promise<PostItem>}    A PostItem representing the posted reply :Promise.
     */
    Save(): Promise<PostItem>;
    /**
     * Saves the post reply in the specified folder. Calling this method results in a call to EWS.
     *
     * @param   {FolderId}   destinationFolderId   The Id of the folder in which to save the post reply.
     * @return  {Promise<PostItem>}    A PostItem representing the posted reply :Promise.
     */
    Save(destinationFolderId: FolderId): Promise<PostItem>;
    /**
     * Saves the post reply in a specified folder. Calling this method results in a call to EWS.
     *
     * @param   {WellKnownFolderName}   destinationFolderName   The name of the folder in which to save the post reply.
     * @return  {Promise<PostItem>}    A PostItem representing the posted reply :Promise.
     */
    Save(destinationFolderName: WellKnownFolderName): Promise<PostItem>;
}
