import { Item } from "../Items/Item";
import { MessageBody } from "../../../ComplexProperties/MessageBody";
import { ResponseMessageType } from "../../../Enumerations/ResponseMessageType";
import { EmailAddressCollection } from "../../../ComplexProperties/EmailAddressCollection";
import { ExchangeVersion } from "../../../Enumerations/ExchangeVersion";
import { ServiceObjectSchema } from "../Schemas/ServiceObjectSchema";
import { EmailMessage } from "../Items/EmailMessage";
import { ResponseObject } from "./ResponseObject";
/**
 * Represents the base class for e-mail related responses (Reply, Reply all and Forward).
 *
 */
export declare class ResponseMessage extends ResponseObject<EmailMessage> {
    private responseType;
    /**
     * Gets a value indicating the type of response this object represents.
     *
     */
    get ResponseType(): ResponseMessageType;
    /**
     * Gets or sets the body of the response.
     *
     */
    get Body(): MessageBody;
    set Body(value: MessageBody);
    /**
     * Gets a list of recipients the response will be sent to.
     *
     */
    get ToRecipients(): EmailAddressCollection;
    /**
     * Gets a list of recipients the response will be sent to as Cc.
     *
     */
    get CcRecipients(): EmailAddressCollection;
    /**
     * Gets a list of recipients this response will be sent to as Bcc.
     *
     */
    get BccRecipients(): EmailAddressCollection;
    /**
     * Gets or sets the subject of this response.
     *
     */
    get Subject(): string;
    set Subject(value: string);
    /**
     * Gets or sets the body prefix of this response. The body prefix will be prepended to the original
    message's body when the response is created.
     *
     */
    get BodyPrefix(): MessageBody;
    set BodyPrefix(value: MessageBody);
    /**
     * Initializes a new instance of the **ResponseMessage** class.
     *
     * @param   {Item}                    referenceItem   The reference item.
     * @param   {ResponseMessageType}     responseType    Type of the response.
     */
    constructor(referenceItem: Item, responseType: ResponseMessageType);
    /**
     * Gets the minimum required server version.
     *
     * @return  {type}      Earliest Exchange version in which this service object type is supported.
     */
    GetMinimumRequiredServerVersion(): ExchangeVersion;
    /**
     * Internal method to return the schema associated with this type of object.
     *
     * @return  {ServiceObjectSchema}      The schema associated with this type of object.
     */
    GetSchema(): ServiceObjectSchema;
    /**
     * Get XML Element Name - workaround for c# attributes
     */
    GetXmlElementName(): string;
    /**
     * This methods lets subclasses of ServiceObject override the default mechanism by which the XML element name associated with their type is retrieved.
     *
     * @return  {string}      The XML element name associated with this type. If this method returns null or empty, the XML element name associated with this type is determined by the EwsObjectDefinition attribute that decorates the type, if present.
     */
    GetXmlElementNameOverride(): string;
}
