import { ExchangeService } from "../ExchangeService";
import { IOutParam } from "../../Interfaces/IOutParam";
import { PropertyDefinitionBase } from "../../PropertyDefinitions/PropertyDefinitionBase";
import { PropertySet } from "../PropertySet";
import { ServiceObjectSchema } from "./Schemas/ServiceObjectSchema";
/**
 * Represents the base abstract class for all item and folder types.
 */
export declare abstract class ServiceObject {
    private lockObject;
    /** workaround for service variable exposer in console.log */
    private getService;
    private setService;
    private propertyBag;
    private xmlElementName;
    /**
     * Gets the schema associated with this type of object.
     */
    get Schema(): ServiceObjectSchema;
    /**
     * Gets the ExchangeService the object is bound to.
     */
    get Service(): ExchangeService;
    /**
     * Indicates whether this object is a real store item, or if it's a local object that has yet to be saved.
     */
    get IsNew(): boolean;
    /**
     * Gets a value indicating whether the object has been modified and should be saved.
     */
    get IsDirty(): boolean;
    /**
     * Defines an event that is triggered when the service object changes.
     */
    private OnChange;
    /**
     * Gets the value of specified property in this instance.
     * This Indexer of c#
     *
     * @param   {PropertyDefinitionBase}   propertyDefinition   Definition of the property to get.
     */
    _getItem(propertyDefinition: PropertyDefinitionBase): any;
    /**
     * Gets the collection of loaded property definitions.
     *
     * @return  {PropertyDefinitionBase[]}      Collection of property definitions.
     */
    GetLoadedPropertyDefinitions(): PropertyDefinitionBase[];
    /**
     * Loads the first class properties. Calling this method results in a call to EWS.
     */
    Load(): Promise<void>;
    /**
     * Loads the specified set of properties. Calling this method results in a call to EWS.
     *
     * @param   {PropertySet}   propertySet   The properties to load.
     */
    Load(propertySet?: PropertySet): Promise<void>;
    /**
     * Try to get the value of a specified property in this instance.
     *
     * @param   {PropertyDefinitionBase}  propertyDefinition   The property definition.
     * @param   {IOutParam<T>}            propertyValue        The property value.
     * @return  {boolean}                 True if property retrieved, false otherwise.
     */
    TryGetProperty<T>(propertyDefinition: PropertyDefinitionBase, propertyValue: IOutParam<T>): boolean;
}
