import * as moment from "moment-timezone";
import { DayOfWeek } from "./Enumerations/DayOfWeek";
import { IOutParam } from "./Interfaces/IOutParam";
import { TimeSpan } from "./TimeSpan";
export declare const msToEpoch: number;
export declare enum DateTimeKind {
    Unspecified = 0,
    Utc = 1,
    Local = 2
}
/**
 * DateTime - basic date time based on moment.js
 */
export declare class DateTime {
    private static readonly DaysToMonth365;
    private static readonly DaysToMonth366;
    kind: DateTimeKind;
    get MomentDate(): moment.Moment;
    get currentUtcOffset(): number;
    private get momentDate();
    private getMomentDate;
    private setMomentDate;
    private originalDateInput;
    static get Now(): DateTime;
    static get UtcNow(): DateTime;
    get TotalMilliSeconds(): number;
    constructor(ms: number);
    constructor(date: DateTime);
    constructor(momentInput: moment.MomentInput);
    constructor(ms: number, kind: DateTimeKind);
    constructor(year: number, month: number, day: number);
    constructor(year: number, month: number, day: number, hour: number, minute: number, second: number);
    constructor(year: number, month: number, day: number, hour: number, minute: number, second: number, millisecond: number);
    constructor(year: number, month: number, day: number, hour: number, minute: number, second: number, millisecond: number, kind: DateTimeKind);
    Add(ts: TimeSpan): DateTime;
    Add(quantity: number, unit: moment.unitOfTime.Base): DateTime;
    static Compare(x: DateTime, y: DateTime): number;
    CompareTo(toDate: DateTime): number;
    Difference(toDate: DateTime): TimeSpan;
    Format(formatting: string): string;
    private static getKindfromMoment;
    static Parse(value: any, kind?: DateTimeKind): DateTime;
    ToISOString(): string;
    toString(): string;
    utcOffset(value: number): void;
    static DateimeStringToTimeZone(dtStr: string, zoneStr: string): DateTime;
    static DateTimeToXSDateTime(dateTime: DateTime): string;
    static DateTimeToXSDate(date: DateTime): string;
    static MinValue: DateTime;
    static MaxValue: DateTime;
    get Date(): DateTime;
    get Day(): number;
    get DayOfWeek(): DayOfWeek;
    get DayOfYear(): number;
    get Hour(): number;
    get Kind(): DateTimeKind;
    get Millisecond(): number;
    get Minute(): number;
    get Month(): number;
    get Second(): number;
    get TimeOfDay(): TimeSpan;
    get Today(): DateTime;
    get Year(): number;
    AddDays(days: number): DateTime;
    AddHours(hours: number): DateTime;
    AddMilliseconds(ms: number): DateTime;
    AddMinutes(minutes: number): DateTime;
    AddMonths(months: number): DateTime;
    AddSeconds(seconds: number): DateTime;
    AddYears(years: number): DateTime;
    static DaysInMonth(year: number, month: number): number;
    Equals(value: any | DateTime): boolean;
    static Equals(t1: DateTime, t2: DateTime): boolean;
    IsDaylightSavingTime(): boolean;
    /**
     *  Checks whether a given year is a leap year. This method returns true if year is a leap year, or false if not.
     * @param {number}  year
     */
    static IsLeapYear(year: number): boolean;
    static SpecifyKind(value: DateTime, kind: DateTimeKind): DateTime;
    Subtract(date: DateTime): TimeSpan;
    Subtract(ts: TimeSpan): DateTime;
    ToLocalTime(): DateTime;
    ToLongDateString(): string;
    ToLongTimeString(): string;
    ToShortDateString(): string;
    ToShortTimeString(): string;
    ToString(): string;
    ToUniversalTime(): DateTime;
    static TryParse(s: string | moment.MomentInput, outDate: IOutParam<DateTime>): boolean;
    valueOf(): number;
}
export declare enum DateTimeStyles {
    None = 0,
    AllowLeadingWhite = 1,
    AllowTrailingWhite = 2,
    /**
     * Summary:
     *	    Extra white-space characters in the middle of the string must be ignored during
     *	    parsing, except if they occur in the System.Globalization.DateTimeFormatInfo
     *	    format patterns.
     */
    AllowInnerWhite = 4,
    /**
     * 	Summary:
     *	    Extra white-space characters anywhere in the string must be ignored during parsing,
     *	    except if they occur in the System.Globalization.DateTimeFormatInfo format patterns.
     *	    This value is a combination of the System.Globalization.DateTimeStyles.AllowLeadingWhite,
     *	    System.Globalization.DateTimeStyles.AllowTrailingWhite, and System.Globalization.DateTimeStyles.AllowInnerWhite
     *	    values.
     */
    AllowWhiteSpaces = 7,
    NoCurrentDateDefault = 8,
    AdjustToUniversal = 16,
    AssumeLocal = 32,
    AssumeUniversal = 64,
    RoundtripKind = 128
}
export declare var unitOfTime: {
    year: moment.unitOfTime.Base;
    years: moment.unitOfTime.Base;
    y: moment.unitOfTime.Base;
    month: moment.unitOfTime.Base;
    months: moment.unitOfTime.Base;
    M: moment.unitOfTime.Base;
    week: moment.unitOfTime.Base;
    weeks: moment.unitOfTime.Base;
    w: moment.unitOfTime.Base;
    day: moment.unitOfTime.Base;
    days: moment.unitOfTime.Base;
    d: moment.unitOfTime.Base;
    hour: moment.unitOfTime.Base;
    hours: moment.unitOfTime.Base;
    h: moment.unitOfTime.Base;
    minute: moment.unitOfTime.Base;
    minutes: moment.unitOfTime.Base;
    m: moment.unitOfTime.Base;
    second: moment.unitOfTime.Base;
    seconds: moment.unitOfTime.Base;
    s: moment.unitOfTime.Base;
    millisecond: moment.unitOfTime.Base;
    milliseconds: moment.unitOfTime.Base;
    ms: moment.unitOfTime.Base;
};
