/**
 * Defines the types of event that can occur in a folder.
 */
export declare enum EventType {
    /**
     * This event is sent to a client application by push notifications to indicate that the subscription is still alive.
     */
    Status = 0,
    /**
     * This event indicates that a new e-mail message was received.
     */
    NewMail = 1,
    /**
     * This event indicates that an item or folder has been deleted.
     */
    Deleted = 2,
    /**
     * This event indicates that an item or folder has been modified.
     */
    Modified = 3,
    /**
     * This event indicates that an item or folder has been moved to another folder.
     */
    Moved = 4,
    /**
     * This event indicates that an item or folder has been copied to another folder.
     */
    Copied = 5,
    /**
     * This event indicates that a new item or folder has been created.
     */
    Created = 6,
    /**
     * This event indicates that free/busy has changed. This is only supported in 2010 SP1 or later
     */
    FreeBusyChanged = 7
}
import { ExchangeVersion } from "./ExchangeVersion";
export declare namespace EventType {
    /**RequiredServerVersionAttribute */
    function RequiredServerVersion(value: EventType): ExchangeVersion;
    /**EwsEnumAttribute */
    function FromEwsEnumString(value: string): EventType;
    /**EwsEnumAttribute */
    function ToEwsEnumString(value: EventType): string;
}
