import { ExchangeService } from "../Core/ExchangeService";
import { FailedSearchMailbox } from "./FailedSearchMailbox";
import { KeywordStatisticsSearchResult } from "./KeywordStatisticsSearchResult";
import { MailboxQuery } from "./MailboxQuery";
import { MailboxStatisticsItem } from "./MailboxStatisticsItem";
import { SearchPreviewItem } from "./SearchPreviewItem";
import { SearchRefinerItem } from "./SearchRefinerItem";
import { SearchResultType } from "../Enumerations/SearchResultType";
/**
 * Represents search mailbox result.
 *
 * @sealed
 */
export declare class SearchMailboxesResult {
    /**
     * Search queries
     */
    SearchQueries: MailboxQuery[];
    /**
     * Result type
     */
    ResultType: SearchResultType;
    /**
     * Item count
     */
    ItemCount: number;
    /**
     * Total size
     * [CLSCompliant(false)]
     */
    Size: number;
    /**
     * Page item count
     */
    PageItemCount: number;
    /**
     * Total page item size
     * [CLSCompliant(false)]
     */
    PageItemSize: number;
    /**
     * Keyword statistics search result
     */
    KeywordStats: KeywordStatisticsSearchResult[];
    /**
     * Search preview items
     */
    PreviewItems: SearchPreviewItem[];
    /**
     * Failed mailboxes
     */
    FailedMailboxes: FailedSearchMailbox[];
    /**
     * Refiners
     */
    Refiners: SearchRefinerItem[];
    /**
     * Mailbox statistics
     */
    MailboxStats: MailboxStatisticsItem[];
    /**
     * Get collection of recipients
     *
     * @param   {any}   jsObject	Json Object converted from XML.
     * @return  {string[]}          Array of recipients
     */
    private static GetRecipients;
    /**
     * Load extended properties from XML.
     *
     * @param   {any}				jsObject	Json Object converted from XML.
     * @param   {ExchangeService}	service	The service.
     * @return  {ExtendedPropertyCollection}     Extended properties collection
     */
    private static LoadExtendedPropertiesXmlJsObject;
    /**
     * Loads service object from XML.
     *
     * @param   {any}				jsObject	Json Object converted from XML.
     * @param   {ExchangeService}	service	The service.
     * @return  {SearchMailboxesResult}     Search result object
     */
    static LoadFromXmlJsObject(jsObject: any, service: ExchangeService): SearchMailboxesResult;
    /**
     * Load keyword stats from XML.
     *
     * @param   {any}   jsObject	Json Object converted from XML.
     * @return  {KeywordStatisticsSearchResult[]}       Array of keyword statistics
     */
    private static LoadKeywordStatsXmlJsObject;
    /**
     * Load preview items from XML.
     *
     * @param   {any}				jsObject	Json Object converted from XML.
     * @param   {ExchangeService}	service	The service.
     * @return  {SearchPreviewItem[]}     Array of preview items
     */
    private static LoadPreviewItemsXmlJsObject;
}
