import { ISelfValidate } from "../../Interfaces/ISelfValidate";
import { MeetingAttendeeType } from "../../Enumerations/MeetingAttendeeType";
/**
 * Represents information about an attendee for which to request availability information.
 *
 * @sealed
 */
export declare class AttendeeInfo implements ISelfValidate {
    /**
     * Gets or sets the SMTP address of this attendee.
     */
    SmtpAddress: string;
    /**
     * Gets or sets the type of this attendee.
     */
    AttendeeType: MeetingAttendeeType;
    /**
     * Gets or sets a value indicating whether times when this attendee is not available should be returned.
     */
    ExcludeConflicts: boolean;
    /**
     * Initializes a new instance of the **AttendeeInfo** class.
     */
    constructor();
    /**
     * Initializes a new instance of the **AttendeeInfo** class.
     *
     * @param   {string}    smtpAddress        The SMTP address of the attendee.
     */
    constructor(smtpAddress: string);
    /**
     * Initializes a new instance of the **AttendeeInfo** class.
     *
     * @param   {string}                smtpAddress        The SMTP address of the attendee.
     * @param   {MeetingAttendeeType}   attendeeType       The yype of the attendee.
     * @param   {boolean}               excludeConflicts   Indicates whether times when this attendee is not available should be returned.
     */
    constructor(smtpAddress: string, attendeeType: MeetingAttendeeType, excludeConflicts: boolean);
    /**
     * Validates this instance.
     *
     * ISelfValidate.Validate
     */
    Validate(): void;
}
