import { Dictionary } from "../AltDictionary";
import { Exception } from "../Exceptions/Exception";
import { ServiceError } from "../Enumerations/ServiceError";
/**
 * Represents SoapFault details.
 *
 * /remarks/    ews-javascript-api -> removing internal modifier to, this class will be used to pass on to error delegate of promise instead of Exceptions.
 *
 * /remarks/    ews-javascript-api -> 0.9 - Extending from Error object to avoid BlueBird errors when promise is rejected without and Error object
 * /remarks/    ews-javascript-api -> 0.9 - extending from Exception which looks like Error to BlueBird. can not extend from Error. Typescript 1.8+ can not extend builtin objects property, it swallows inheriting properties see  https://github.com/Microsoft/TypeScript/wiki/Breaking-Changes#extending-built-ins-like-error-array-and-map-may-no-longer-work
 */
export declare class SoapFaultDetails extends Exception {
    private faultCode;
    private faultString;
    private faultActor;
    /**
     * Response code returned by EWS requests.
     * Default to InternalServerError.
     */
    private responseCode;
    /**
     * Message text of the error.
     */
    message: string;
    /**
     * This is returned by Availability requests.
     */
    private errorCode;
    /**
     * This is returned by UM requests. It's the name of the exception that was raised.
     */
    private exceptionType;
    /**
     * When a schema validation error is returned, this is the line number in the request where the error occurred.
     */
    private lineNumber;
    /**
     * When a schema validation error is returned, this is the offset into the line of the request where the error occurred.
     */
    private positionWithinLine;
    /**
     * Dictionary of key/value pairs from the MessageXml node in the fault. Usually empty but there are a few cases where SOAP faults may include MessageXml details (e.g. CASOverBudgetException includes BackoffTime value).
     */
    private errorDetails;
    set FaultCode(value: string);
    set FaultString(value: string);
    set FaultActor(value: string);
    set ResponseCode(value: ServiceError);
    set Message(value: string);
    set ErrorCode(value: ServiceError);
    set ExceptionType(value: string);
    set LineNumber(value: number);
    set PositionWithinLine(value: number);
    set ErrorDetails(value: Dictionary<string, string>);
    /**
     * Exception generated based on ExchangeService parsing
     * Exception property to carry this to caller.
     */
    Exception: Exception;
    /**
     * ews-javascript-api specific: HTTP status code
     */
    HttpStatusCode: number;
    /**
     * Parses the detail node.
     *
     * @param   {any}   jsObject   The detail node.
     */
    private ParseDetailNode;
    /**
     * Parses the message XML.
     *
     * @param   {any}   jsObject   The message Xml object.
     */
    private ParseMessageXml;
}
