import { Dictionary } from "../AltDictionary";
import { EventType } from "../Enumerations/EventType";
import { FolderEvent } from "./FolderEvent";
import { ItemEvent } from "./ItemEvent";
import { NotificationEvent } from "./NotificationEvent";
/**
 * Represents a collection of notification events.
 */
export declare class GetEventsResults {
    /**
     * Map XML element name to notification event type.
     *
     * /remarks/ 	If you add a new notification event type, you'll need to add a new entry to the dictionary here.
     */
    private static xmlElementNameToEventTypeMap;
    /**
     * Gets the XML element name to event type mapping.
     *
     * @value	The XML element name to event type mapping.
     */
    static get XmlElementNameToEventTypeMap(): Dictionary<string, EventType>;
    /**
     * Watermark in event.
     */
    private newWatermark;
    /**
     * Subscription id.
     */
    private subscriptionId;
    /**
     * Previous watermark.
     */
    private previousWatermark;
    /**
     * True if more events available for this subscription.
     */
    private moreEventsAvailable;
    /**
     * Collection of notification events.
     */
    private events;
    /**
     * Gets the collection of folder events.
     *
     * @value	The folder events.
     */
    get FolderEvents(): FolderEvent[];
    /**
     * Gets the collection of item events.
     *
     * @value	The item events.
     */
    get ItemEvents(): ItemEvent[];
    /**
     * Gets the collection of all events.
     *
     * @value	The events.
     */
    get AllEvents(): NotificationEvent[];
    /**
     * Loads the events from XML.
     *
     * @param   {any[]}               jsEventsArray         The json events array.
     * @param   {string}     		  xmlElementName		Name of the element.
     * @param   {ExchangeService}     service               The service.
     */
    private LoadEventsFromXmlJsObject;
}
