import { DateTime } from "../DateTime";
import { EventType } from "../Enumerations/EventType";
import { FolderId } from "../ComplexProperties/FolderId";
/**
 * Represents an event as exposed by push and pull notifications.
 */
export declare abstract class NotificationEvent {
    /**
     * Type of this event.
     */
    private eventType;
    /**
     * Date and time when the event occurred.
     */
    private timestamp;
    /**
     * Id of parent folder of the item or folder this event applies to.
     */
    private parentFolderId;
    /**
     * Id of the old prarent foldero of the item or folder this event applies to.
     * This property is only meaningful when EventType is equal to either EventType.Moved or EventType.Copied.
     * For all other event types, oldParentFolderId will be null.
     */
    private oldParentFolderId;
    /**
     * Gets the type of this event.
     */
    get EventType(): EventType;
    /**
     * Gets the date and time when the event occurred.
     */
    get TimeStamp(): DateTime;
    /**
     * Gets the Id of the parent folder of the item or folder this event applie to.
     */
    get ParentFolderId(): FolderId;
    set ParentFolderId(value: FolderId);
    /**
     * Gets the Id of the old parent folder of the item or folder this event applies to.
     * OldParentFolderId is only meaningful when EventType is equal to either EventType.Moved or EventType.Copied.
     * For all other event types, OldParentFolderId is null.
     */
    get OldParentFolderId(): FolderId;
    set OldParentFolderId(value: FolderId);
}
