import { DateTime } from "../DateTime";
import { ItemTraversal } from "../Enumerations/ItemTraversal";
import { ViewBase } from "./ViewBase";
/**
 * Represents a date range view of appointments in calendar folder search operations.
 */
export declare class CalendarView extends ViewBase {
    private traversal;
    private maxItemsReturned;
    private startDate;
    private endDate;
    /**
     * Gets or sets the start date.
     */
    get StartDate(): DateTime;
    set StartDate(value: DateTime);
    /**
     * Gets or sets the end date.
     */
    get EndDate(): DateTime;
    set EndDate(value: DateTime);
    /**
     * The maximum number of items the search operation should return.
     */
    get MaxItemsReturned(): number;
    set MaxItemsReturned(value: number);
    /**
     * Gets or sets the search traversal mode. Defaults to ItemTraversal.Shallow.
     */
    get Traversal(): ItemTraversal;
    set Traversal(value: ItemTraversal);
    /**
     * Initializes a new instance of CalendarView.
     *
     * @param   {DateTime}  startDate          The start date.
     * @param   {DateTime}  endDate            The end date.
     */
    constructor(startDate: DateTime, endDate: DateTime);
    /**
     * Initializes a new instance of CalendarView.
     *
     * @param   {DateTime}  startDate          The start date.
     * @param   {DateTime}  endDate            The end date.
     * @param   {number}    maxItemsReturned   The maximum number of items the search operation should return.
     */
    constructor(startDate: DateTime, endDate: DateTime, maxItemsReturned: number);
}
