import { ConversationQueryTraversal } from "../Enumerations/ConversationQueryTraversal";
import { OffsetBasePoint } from "../Enumerations/OffsetBasePoint";
import { OrderByCollection } from "./OrderByCollection";
import { ViewFilter } from "../Enumerations/ViewFilter";
import { PagedView } from "./PagedView";
/**
 * Represents the view settings in a folder search operation.
 *
 * @sealed
 */
export declare class ConversationIndexedItemView extends PagedView {
    private orderBy;
    private traversal;
    private viewFilter;
    /**
     * Gets the properties against which the returned items should be ordered.
     */
    get OrderBy(): OrderByCollection;
    /**
     * Gets or sets the conversation query traversal mode.
     *
     * @Nullable
     */
    get Traversal(): ConversationQueryTraversal;
    set Traversal(value: ConversationQueryTraversal);
    /**
     * Gets or sets the view filter.
     *
     * @Nullable
     */
    get ViewFilter(): ViewFilter;
    set ViewFilter(value: ViewFilter);
    /**
     * Initializes a new instance of the **ItemView** class.
     *
     * @param   {number}   pageSize          The maximum number of elements the search operation should return.
     */
    constructor(pageSize: number);
    /**
     * Initializes a new instance of the **ItemView** class.
     *
     * @param   {number}   pageSize          The maximum number of elements the search operation should return.
     * @param   {number}   offset            The offset of the view from the base point.
     */
    constructor(pageSize: number, offset: number);
    /**
     * Initializes a new instance of the **ItemView** class.
     *
     * @param   {number}   pageSize          The maximum number of elements the search operation should return.
     * @param   {number}   offset            The offset of the view from the base point.
     * @param   {number}   offsetBasePoint   The base point of the offset.
     */
    constructor(pageSize: number, offset: number, offsetBasePoint: OffsetBasePoint);
}
