import { HighlightTerm } from "../ComplexProperties/HighlightTerm";
import { Item } from "../Core/ServiceObjects/Items/Item";
/**
 * Represents the results of an item search operation.
 *
 * @sealed
 * @type    {TItem}  Item type
 */
export declare class FindItemsResults<TItem extends Item> {
    private totalCount;
    private nextPageOffset;
    private moreAvailable;
    private items;
    private highlightTerms;
    /**
     * Gets the total number of items matching the search criteria available in the searched folder.
     */
    get TotalCount(): number;
    set TotalCount(value: number);
    /**
     * Gets the offset that should be used with ItemView to retrieve the next page of items in a FindItems operation.
     */
    get NextPageOffset(): number;
    set NextPageOffset(value: number);
    /**
     * Gets a value indicating whether more items matching the search criteria are available in the searched folder.
     */
    get MoreAvailable(): boolean;
    set MoreAvailable(value: boolean);
    /**
     * Gets a collection containing the items that were found by the search operation.
     */
    get Items(): TItem[];
    /**
     * Gets a collection containing the highlight terms that were found by the search operation.
     */
    get HighlightTerms(): HighlightTerm[];
}
