import { AggregateType } from "../Enumerations/AggregateType";
import { ISelfValidate } from "../Interfaces/ISelfValidate";
import { PropertyDefinitionBase } from "../PropertyDefinitions/PropertyDefinitionBase";
import { SortDirection } from "../Enumerations/SortDirection";
/**
 * Represents grouping options in item search operations.
 *
 * @sealed
 */
export declare class Grouping implements ISelfValidate {
    /**
     * Gets or sets the sort direction.
     */
    SortDirection: SortDirection;
    /**
     * Gets or sets the property to group on.
     */
    GroupOn: PropertyDefinitionBase;
    /**
     * Gets or sets the property to aggregate on.
     */
    AggregateOn: PropertyDefinitionBase;
    /**
     * Gets or sets the types of aggregate to calculate.
     */
    AggregateType: AggregateType;
    /** no need for setter getter */
    /**
     * Initializes a new instance of the **Grouping** class.
     */
    constructor();
    /**
     * Initializes a new instance of the **Grouping** class.
     *
     * @param   {PropertyDefinitionBase}   groupOn         The property to group on.
     * @param   {SortDirection}   sortDirection   The sort direction.
     * @param   {PropertyDefinitionBase}   aggregateOn     The property to aggregate on.
     * @param   {AggregateType}   aggregateType   The type of aggregate to calculate.
     */
    constructor(groupOn: PropertyDefinitionBase, sortDirection: SortDirection, aggregateOn: PropertyDefinitionBase, aggregateType: AggregateType);
    /**
     * Validates this grouping.
     */
    private InternalValidate;
    /**
     * Implements ISelfValidate.Validate. Validates this grouping.
     */
    Validate(): void;
}
