import { IEnumerable } from "../Interfaces/IEnumerable";
import { IOutParam } from "../Interfaces/IOutParam";
import { KeyValuePair } from "../AltDictionary";
import { PropertyDefinitionBase } from "../PropertyDefinitions/PropertyDefinitionBase";
import { SortDirection } from "../Enumerations/SortDirection";
export type PropertyDefinitionSortDirectionPair = KeyValuePair<PropertyDefinitionBase, SortDirection>;
/**
 * Represents an ordered collection of property definitions qualified with a sort direction.
 *
 * @sealed
 */
export declare class OrderByCollection implements IEnumerable<PropertyDefinitionSortDirectionPair> {
    private propDefSortOrderPairList;
    /**
     * Gets the number of elements contained in the collection.
     */
    get Count(): number;
    /**
     * Gets the element at the specified index from the collection.
     *
     * @param   {number}   index   Index.
     */
    _getItem(index: number): PropertyDefinitionSortDirectionPair;
    /**
     * Adds the specified property definition / sort direction pair to the collection.
     *
     * @param   {PropertyDefinitionBase}    propertyDefinition   The property definition.
     * @param   {SortDirection}             sortDirection        The sort direction.
     */
    Add(propertyDefinition: PropertyDefinitionBase, sortDirection: SortDirection): void;
    /**
     * Removes all elements from the collection.
     */
    Clear(): void;
    /**
     *  Returns an enumerator that iterates through the collection. this case this.propDefSortOrderPairList
     */
    GetEnumerator(): PropertyDefinitionSortDirectionPair[];
    /**
     * Tries to get the value for a property definition in the collection.
     *
     * @param   {PropertyDefinitionBase}    propertyDefinition   The property definition.
     * @param   {IOutParam<SortDirection>}  sortDirection        The sort direction.
     * @return  {boolean}                   True if collection contains property definition, otherwise false.
     */
    TryGetValue(propertyDefinition: PropertyDefinitionBase, sortDirection: IOutParam<SortDirection>): boolean;
}
