import { OffsetBasePoint } from "../Enumerations/OffsetBasePoint";
import { ViewBase } from "./ViewBase";
/**
 * Represents a view settings that support paging in a search operation.
 */
export declare abstract class PagedView extends ViewBase {
    private pageSize;
    private offsetBasePoint;
    private offset;
    /**
     * The maximum number of items or folders the search operation should return.
     */
    get PageSize(): number;
    set PageSize(value: number);
    /**
     * Gets or sets the base point of the offset.
     */
    get OffsetBasePoint(): OffsetBasePoint;
    set OffsetBasePoint(value: OffsetBasePoint);
    /**
     * Gets or sets the offset.
     */
    get Offset(): number;
    set Offset(value: number);
    /**
     * Initializes a new instance of the **PagedView** class.
     *
     * @param   {number}   pageSize          The maximum number of elements the search operation should return.
     */
    constructor(pageSize: number);
    /**
     * Initializes a new instance of the **PagedView** class.
     *
     * @param   {number}   pageSize          The maximum number of elements the search operation should return.
     * @param   {number}   offset            The offset of the view from the base point.
     */
    constructor(pageSize: number, offset: number);
    /**
     * Initializes a new instance of the **PagedView** class.
     *
     * @param   {number}   pageSize          The maximum number of elements the search operation should return.
     * @param   {number}   offset            The offset of the view from the base point.
     * @param   {number}   offsetBasePoint   The base point of the offset.
     */
    constructor(pageSize: number, offset: number, offsetBasePoint: OffsetBasePoint);
}
