import { ItemTraversal } from "../Enumerations/ItemTraversal";
import { OffsetBasePoint } from "../Enumerations/OffsetBasePoint";
import { OrderByCollection } from "./OrderByCollection";
import { SearchFilter } from "./Filters/SearchFilter";
import { ViewBase } from "./ViewBase";
/**
 * Represents the view settings in a folder search operation.
 *
 * @sealed
 */
export declare class SeekToConditionItemView extends ViewBase {
    private pageSize;
    private traversal;
    private condition;
    private offsetBasePoint;
    private orderBy;
    private serviceObjType;
    /**
     * The maximum number of items or folders the search operation should return.
     */
    get PageSize(): number;
    set PageSize(value: number);
    /**
     * Gets or sets the base point of the offset.
     */
    get OffsetBasePoint(): OffsetBasePoint;
    set OffsetBasePoint(value: OffsetBasePoint);
    /**
     * Gets or sets the condition for seek.
     * Available search filter classes include SearchFilter.IsEqualTo, SearchFilter.ContainsSubstring and SearchFilter.SearchFilterCollection.
     * If SearchFilter is null, no search filters are applied.
     */
    get Condition(): SearchFilter;
    set Condition(value: SearchFilter);
    /**
     * Gets or sets the search traversal mode. Defaults to ItemTraversal.Shallow.
     */
    get Traversal(): ItemTraversal;
    set Traversal(value: ItemTraversal);
    /**
     * Gets the properties against which the returned items should be ordered.
     */
    get OrderBy(): OrderByCollection;
    /**
     * Initializes a new instance of the **SeekToConditionItemView** class.
     *
     * @param   {SearchFilter}	condition         Condition to be used when seeking.
     * @param   {number}		pageSize          The maximum number of elements the search operation should return.
     */
    constructor(condition: SearchFilter, pageSize: number);
    /**
     * Initializes a new instance of the **SeekToConditionItemView** class.
     *
     * @param   {SearchFilter}   	condition         Condition to be used when seeking.
     * @param   {number}   			pageSize          The maximum number of elements the search operation should return.
     * @param   {OffsetBasePoint}   offsetBasePoint   The base point of the offset.
     */
    constructor(condition: SearchFilter, pageSize: number, offsetBasePoint: OffsetBasePoint);
}
