import { IEnumerable } from "../Interfaces/IEnumerable";
import { Change } from "./Change";
/**
 * Represents a collection of changes as returned by a synchronization operation.
 *
 * @sealed
 * @typeparam	{TChange}	Type representing the type of change (e.g. FolderChange or ItemChange)
 */
export declare class ChangeCollection<TChange extends Change> implements IEnumerable<TChange> {
    ___typeGenerics: string[];
    private changes;
    private syncState;
    private moreChangesAvailable;
    /**
     * Gets the number of changes in the collection.
     */
    get Count(): number;
    /**
     * Gets the SyncState blob returned by a synchronization operation.
     */
    get SyncState(): string;
    set SyncState(value: string);
    /**
     * Gets a value indicating whether the there are more changes to be synchronized from the server.
     */
    get MoreChangesAvailable(): boolean;
    set MoreChangesAvailable(value: boolean);
    /**
     * Gets an individual change from the change collection.
     *
     * @param   {number}   index   Zero-based index.
     * @return  {TChange}		An single change.
     */
    _getItem(index: number): TChange;
    /**
     *  Returns an enumerator that iterates through the collection. this case this.changes
     */
    GetEnumerator(): TChange[];
}
