import { DateTime } from "./DateTime";
import { DayOfWeek } from "../js/Enumerations/DayOfWeek";
import { TimeSpan } from "./TimeSpan";
/**
* TimeZoneInfo
*/
export declare class TimeZoneInfo {
    private static _localTimeZone;
    private readonly _id;
    private _ianaId;
    private readonly _displayName;
    private readonly _standardDisplayName;
    private readonly _daylightDisplayName;
    private readonly _baseUtcOffset;
    private readonly _supportsDaylightSavingTime;
    private readonly _adjustmentRules;
    private static readonly UtcId;
    private static readonly LocalId;
    private static readonly s_utcTimeZone;
    private static readonly s_maxDateOnly;
    private static readonly s_minDateOnly;
    get Id(): string;
    get IanaId(): string;
    get DisplayName(): string;
    get StandardName(): string;
    get DaylightName(): string;
    get BaseUtcOffset(): TimeSpan;
    get SupportsDaylightSavingTime(): boolean;
    static get Local(): TimeZoneInfo;
    static get Utc(): TimeZoneInfo;
    private constructor();
    static ConvertTime(dateTime: DateTime, sourceTimeZone: TimeZoneInfo, destinationTimeZone: TimeZoneInfo): DateTime;
    private static CreateLocal;
    static CreateCustomTimeZone(id: string, baseUtcOffset: TimeSpan, displayName: string, standardDisplayName: string): TimeZoneInfo;
    static CreateCustomTimeZone(id: string, baseUtcOffset: TimeSpan, displayName: string, standardDisplayName: string, daylightDisplayName: string, adjustmentRules: TimeZoneInfo.AdjustmentRule[]): TimeZoneInfo;
    static CreateCustomTimeZone(id: string, baseUtcOffset: TimeSpan, displayName: string, standardDisplayName: string, daylightDisplayName: string, adjustmentRules: TimeZoneInfo.AdjustmentRule[], disableDaylightSavingTime: boolean): TimeZoneInfo;
    static AddTimeZoneMapping(source: string, mappedTz: string): void;
    static FindSystemTimeZoneById(zoneName: string): TimeZoneInfo;
    static get ListWindowsTimeZones(): () => string[];
    private static GetCorrespondingKind;
    static GuessLocalTimeZone(): string;
    HasSameRules(other: TimeZoneInfo): boolean;
}
export declare namespace TimeZoneInfo {
    enum TimeZoneInfoOptions {
        None = 1,
        NoThrowOnInvalidTime = 2
    }
    class AdjustmentRule {
        private readonly _dateStart;
        private readonly _dateEnd;
        private readonly _daylightDelta;
        private readonly _daylightTransitionStart;
        private readonly _daylightTransitionEnd;
        private readonly _baseUtcOffsetDelta;
        private readonly _noDaylightTransitions;
        get DateStart(): DateTime;
        get DateEnd(): DateTime;
        get DaylightDelta(): TimeSpan;
        get DaylightTransitionStart(): TransitionTime;
        get DaylightTransitionEnd(): TransitionTime;
        private constructor();
        Equals(other: AdjustmentRule): boolean;
        static CreateAdjustmentRule(dateStart: DateTime, dateEnd: DateTime, daylightDelta: TimeSpan, daylightTransitionStart: TransitionTime, daylightTransitionEnd: TransitionTime): AdjustmentRule;
        private static ValidateAdjustmentRule;
    }
    class TransitionTime {
        private readonly _timeOfDay;
        private readonly _month;
        private readonly _week;
        private readonly _day;
        private readonly _dayOfWeek;
        private readonly _isFixedDateRule;
        get TimeOfDay(): DateTime;
        get Month(): number;
        get Week(): number;
        get Day(): number;
        get DayOfWeek(): DayOfWeek;
        get IsFixedDateRule(): boolean;
        Equals(other: TransitionTime): boolean;
        GetHashCode(): number;
        private constructor();
        static CreateFixedDateRule(timeOfDay: DateTime, month: number, day: number): TransitionTime;
        static CreateFloatingDateRule(timeOfDay: DateTime, month: number, week: number, dayOfWeek: DayOfWeek): TransitionTime;
        private static ValidateTransitionTime;
    }
}
